@@ -19,11 +19,10 @@
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-
 /**
  * @see Zend_Cache_Backend_Interface
  */
-require_once 'Zend/Cache/Backend/Interface.php';
+require_once 'Zend/Cache/Backend/ExtendedInterface.php';
 
 /**
  * @see Zend_Cache_Backend
@@ -37,7 +36,7 @@ require_once 'Zend/Cache/Backend.php';
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
-class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_Backend_Interface
+class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_Backend_ExtendedInterface
 {
     /**
      * Available options
@@ -80,11 +79,11 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
      *
      * =====> (int) cache_file_umask :
      * - Umask for cache files
-     * 
+     *
      * =====> (int) metatadatas_array_max_size :
      * - max size for the metadatas array (don't change this value unless you
      *   know what you are doing)
-     * 
+     *
      * @var array available options
      */
     protected $_options = array(
@@ -98,10 +97,10 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         'cache_file_umask' => 0600,
         'metadatas_array_max_size' => 100
     );
-    
+
     /**
      * Array of metadatas (each item is an associative array)
-     * 
+     *
      * @var array
      */
     private $_metadatasArray = array();
@@ -114,7 +113,7 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
      * @throws Zend_Cache_Exception
      * @return void
      */
-    public function __construct($options = array())
+    public function __construct(array $options = array())
     {
         parent::__construct($options);
         if (!is_null($this->_options['cache_dir'])) { // particular case for this option
@@ -130,6 +129,14 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         if ($this->_options['metadatas_array_max_size'] < 10) {
             Zend_Cache::throwException('Invalid metadatas_array_max_size, must be > 10');
         }
+        if (isset($options['hashed_directory_umask']) && is_string($options['hashed_directory_umask'])) {
+            // See #ZF-4422
+            $this->_options['hashed_directory_umask'] = octdec($this->_options['hashed_directory_umask']);
+        }
+        if (isset($options['cache_file_umask']) && is_string($options['cache_file_umask'])) {
+            // See #ZF-4422
+            $this->_options['cache_file_umask'] = octdec($this->_options['cache_file_umask']);
+        }
     }
 
     /**
@@ -213,18 +220,15 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         clearstatcache();
         $file = $this->_file($id);
         $path = $this->_path($id);
-        $firstTry = true;
-        $result = false;      
         if ($this->_options['hashed_directory_level'] > 0) {
             if (!is_writable($path)) {
                 // maybe, we just have to build the directory structure
-                @mkdir($this->_path($id), $this->_options['hashed_directory_umask'], true);
-                @chmod($this->_path($id), $this->_options['hashed_directory_umask']); // see #ZF-320 (this line is required in some configurations)      
+                $this->_recursiveMkdirAndChmod($id);
             }
             if (!is_writable($path)) {
-                return false;    
+                return false;
             }
-        }  
+        }
         if ($this->_options['read_control']) {
             $hash = $this->_hash($data, $this->_options['read_control_type']);
         } else {
@@ -238,7 +242,7 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         );
         $res = $this->_setMetadatas($id, $metadatas);
         if (!$res) {
-            // FIXME : log
+            $this->_log('Zend_Cache_Backend_File::save() / error on saving metadata');
             return false;
         }
         $res = $this->_filePutContents($file, $data);
@@ -267,6 +271,8 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
      *                     ($tags can be an array of strings or a single string)
      * 'notMatchingTag' => remove cache entries not matching one of the given tags
      *                     ($tags can be an array of strings or a single string)
+     * 'matchingAnyTag' => remove cache entries matching any given tags
+     *                     ($tags can be an array of strings or a single string)
      *
      * @param string $mode clean mode
      * @param tags array $tags array of tags
@@ -278,6 +284,167 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         clearstatcache();
         return $this->_clean($this->_options['cache_dir'], $mode, $tags);
     }
+    
+    /**
+     * Return an array of stored cache ids
+     * 
+     * @return array array of stored cache ids (string)
+     */
+    public function getIds()
+    {
+        return $this->_get($this->_options['cache_dir'], 'ids', array());
+    }
+    
+    /**
+     * Return an array of stored tags
+     *
+     * @return array array of stored tags (string)
+     */
+    public function getTags()
+    {
+        return $this->_get($this->_options['cache_dir'], 'tags', array());
+    }
+    
+    /**
+     * Return an array of stored cache ids which match given tags
+     * 
+     * In case of multiple tags, a logical AND is made between tags
+     *
+     * @param array $tags array of tags
+     * @return array array of matching cache ids (string)
+     */
+    public function getIdsMatchingTags($tags = array())
+    {
+        return $this->_get($this->_options['cache_dir'], 'matching', $tags);
+    }
+    
+    /**
+     * Return an array of stored cache ids which don't match given tags
+     * 
+     * In case of multiple tags, a logical OR is made between tags
+     *
+     * @param array $tags array of tags
+     * @return array array of not matching cache ids (string)
+     */    
+    public function getIdsNotMatchingTags($tags = array())
+    {
+        return $this->_get($this->_options['cache_dir'], 'notMatching', $tags);
+    }
+    
+    /**
+     * Return an array of stored cache ids which match any given tags
+     * 
+     * In case of multiple tags, a logical AND is made between tags
+     *
+     * @param array $tags array of tags
+     * @return array array of any matching cache ids (string)
+     */
+    public function getIdsMatchingAnyTags($tags = array())
+    {
+        return $this->_get($this->_options['cache_dir'], 'matchingAny', $tags);
+    }
+    
+    /**
+     * Return the filling percentage of the backend storage
+     *
+     * @throws Zend_Cache_Exception
+     * @return int integer between 0 and 100
+     */
+    public function getFillingPercentage()
+    {
+        $free = disk_free_space($this->_options['cache_dir']);
+        $total = disk_total_space($this->_options['cache_dir']);
+        if ($total == 0) {
+            Zend_Cache::throwException('can\'t get disk_total_space');
+        } else {
+            if ($free >= $total) {
+                return 100;
+            }
+            return ((int) (100. * ($total - $free) / $total));
+        }
+    }
+    
+    /**
+     * Return an array of metadatas for the given cache id
+     *
+     * The array must include these keys :
+     * - expire : the expire timestamp
+     * - tags : a string array of tags
+     * - mtime : timestamp of last modification time
+     * 
+     * @param string $id cache id
+     * @return array array of metadatas (false if the cache id is not found)
+     */
+    public function getMetadatas($id)
+    {
+        $metadatas = $this->_getMetadatas($id);
+        if (!$metadatas) {
+            return false;
+        }
+        if (time() > $metadatas['expire']) {
+            return false;
+        }
+        return array(
+            'expire' => $metadatas['expire'],
+            'tags' => $metadatas['tags'],
+            'mtime' => $metadatas['mtime']
+        );
+    }
+    
+    /**
+     * Give (if possible) an extra lifetime to the given cache id
+     *
+     * @param string $id cache id
+     * @param int $extraLifetime
+     * @return boolean true if ok
+     */
+    public function touch($id, $extraLifetime)
+    {
+        $metadatas = $this->_getMetadatas($id);
+        if (!$metadatas) {
+            return false;
+        }
+        if (time() > $metadatas['expire']) {
+            return false;
+        }
+        $newMetadatas = array(
+            'hash' => $metadatas['hash'],
+            'mtime' => time(),
+            'expire' => $metadatas['expire'] + $extraLifetime,
+            'tags' => $metadatas['tags']
+        );
+        $res = $this->_setMetadatas($id, $newMetadatas);
+        if (!$res) {
+            return false;
+        }
+        return true;
+    }
+    
+    /**
+     * Return an associative array of capabilities (booleans) of the backend
+     * 
+     * The array must include these keys :
+     * - automatic_cleaning (is automating cleaning necessary)
+     * - tags (are tags supported)
+     * - expired_read (is it possible to read expired cache records
+     *                 (for doNotTestCacheValidity option for example))
+     * - priority does the backend deal with priority when saving
+     * - infinite_lifetime (is infinite lifetime can work with this backend)
+     * - get_list (is it possible to get the list of cache ids and the complete list of tags)
+     * 
+     * @return array associative of with capabilities
+     */
+    public function getCapabilities()
+    {
+        return array(
+            'automatic_cleaning' => true,
+            'tags' => true,
+            'expired_read' => true,
+            'priority' => false,
+            'infinite_lifetime' => true,
+            'get_list' => true
+        );
+    }
 
     /**
      * PUBLIC METHOD FOR UNIT TESTING ONLY !
@@ -296,8 +463,8 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
     }
 
     /**
-     * Get a metadatas record 
-     * 
+     * Get a metadatas record
+     *
      * @param  string $id  Cache id
      * @return array|false Associative array of metadatas
      */
@@ -314,10 +481,10 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
             return $metadatas;
         }
     }
-    
+
     /**
      * Set a metadatas record
-     * 
+     *
      * @param  string $id        Cache id
      * @param  array  $metadatas Associative array of metadatas
      * @param  boolean $save     optional pass false to disable saving to file
@@ -338,10 +505,10 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         $this->_metadatasArray[$id] = $metadatas;
         return true;
     }
-    
+
     /**
      * Drop a metadata record
-     * 
+     *
      * @param  string $id Cache id
      * @return boolean True if no problem
      */
@@ -351,9 +518,9 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
             unset($this->_metadatasArray[$id]);
         }
         $file = $this->_metadatasFile($id);
-        return $this->_remove($file);       
+        return $this->_remove($file);
     }
-    
+
     /**
      * Clear the metadatas array
      *
@@ -363,10 +530,10 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
     {
         $this->_metadatasArray = array();
     }
-    
+
     /**
-     * Load metadatas from disk 
-     * 
+     * Load metadatas from disk
+     *
      * @param  string $id Cache id
      * @return array|false Metadatas associative array
      */
@@ -380,10 +547,10 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         $tmp = @unserialize($result);
         return $tmp;
     }
-    
+
     /**
      * Save metadatas to disk
-     * 
+     *
      * @param  string $id        Cache id
      * @param  array  $metadatas Associative array
      * @return boolean True if no problem
@@ -397,10 +564,10 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         }
         return true;
     }
-    
+
     /**
      * Make and return a file name (with path) for metadatas
-     * 
+     *
      * @param  string $id Cache id
      * @return string Metadatas file name (with path)
      */
@@ -410,10 +577,10 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         $fileName = $this->_idToFileName('internal-metadatas---' . $id);
         return $path . $fileName;
     }
-    
+
     /**
      * Check if the given filename is a metadatas one
-     * 
+     *
      * @param  string $fileName File name
      * @return boolean True if it's a metadatas one
      */
@@ -426,7 +593,7 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
             return false;
         }
     }
-    
+
     /**
      * Remove a file
      *
@@ -459,6 +626,8 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
      *                                               ($tags can be an array of strings or a single string)
      * Zend_Cache::CLEANING_MODE_NOT_MATCHING_TAG => remove cache entries not {matching one of the given tags}
      *                                               ($tags can be an array of strings or a single string)
+     * Zend_Cache::CLEANING_MODE_MATCHING_ANY_TAG => remove cache entries matching any given tags
+     *                                               ($tags can be an array of strings or a single string)
      *
      * @param  string $dir  Directory to clean
      * @param  string $mode Clean mode
@@ -490,7 +659,7 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
                 $metadatas = $this->_getMetadatas($id);
                 if ($metadatas === FALSE) {
                     $metadatas = array('expire' => 1, 'tags' => array());
-                }          
+                }
                 switch ($mode) {
                     case Zend_Cache::CLEANING_MODE_ALL:
                         $res = $this->remove($id);
@@ -527,11 +696,23 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
                         }
                         if (!$matching) {
                             $result = ($result) && $this->remove($id);
-                        }                       
+                        }
+                        break;
+                    case Zend_Cache::CLEANING_MODE_MATCHING_ANY_TAG:
+                        $matching = false;
+                        foreach ($tags as $tag) {
+                            if (in_array($tag, $metadatas['tags'])) {
+                                $matching = true;
+                                break;
+                            }
+                        }
+                        if ($matching) {
+                            $result = ($result) && ($this->remove($id));
+                        }
                         break;
                     default:
                         Zend_Cache::throwException('Invalid mode for clean() method');
-                        break;     
+                        break;
                 }
             }
             if ((is_dir($file)) and ($this->_options['hashed_directory_level']>0)) {
@@ -545,6 +726,84 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         }
         return $result;
     }
+    
+    private function _get($dir, $mode, $tags = array())
+    {
+        if (!is_dir($dir)) {
+            return false;
+        }
+        $result = array();
+        $prefix = $this->_options['file_name_prefix'];
+        $glob = @glob($dir . $prefix . '--*');
+        if ($glob === false) {
+            return true;
+        }
+        foreach ($glob as $file)  {
+            if (is_file($file)) {
+                $fileName = basename($file);
+                $id = $this->_fileNameToId($fileName);
+                $metadatas = $this->_getMetadatas($id);
+                if ($metadatas === FALSE) {
+                    continue;
+                }
+                if (time() > $metadatas['expire']) {
+                    continue;
+                }
+                switch ($mode) {
+                    case 'ids':
+                        $result[] = $id;
+                        break;
+                    case 'tags':
+                        $result = array_unique(array_merge($result, $metadatas['tags']));
+                        break;
+                    case 'matching':
+                        $matching = true;
+                        foreach ($tags as $tag) {
+                            if (!in_array($tag, $metadatas['tags'])) {
+                                $matching = false;
+                                break;
+                            }
+                        }
+                        if ($matching) {
+                            $result[] = $id;
+                        }
+                        break;
+                    case 'notMatching':
+                        $matching = false;
+                        foreach ($tags as $tag) {
+                            if (in_array($tag, $metadatas['tags'])) {
+                                $matching = true;
+                                break;
+                            }
+                        }
+                        if (!$matching) {
+                            $result[] = $id;
+                        }
+                        break;
+                    case 'matchingAny':
+                        $matching = false;
+                        foreach ($tags as $tag) {
+                            if (in_array($tag, $metadatas['tags'])) {
+                                $matching = true;
+                                break;
+                            }
+                        }
+                        if ($matching) {
+                            $result[] = $id;
+                        }
+                        break;
+                    default:
+                        Zend_Cache::throwException('Invalid mode for _get() method');
+                        break;
+                }
+            }
+            if ((is_dir($file)) and ($this->_options['hashed_directory_level']>0)) {
+                // Recursive call
+                $result = array_unique(array_merge($result, $this->_get($file . DIRECTORY_SEPARATOR, $mode, $tags)));
+            }
+        }
+        return array_unique($result);
+    }
 
     /**
      * Compute & return the expire time
@@ -595,10 +854,10 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         $result = $prefix . '---' . $id;
         return $result;
     }
-    
+
     /**
      * Make and return a file name (with path)
-     * 
+     *
      * @param  string $id Cache id
      * @return string File name (with path)
      */
@@ -608,26 +867,54 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         $fileName = $this->_idToFileName($id);
         return $path . $fileName;
     }
-    
+
     /**
      * Return the complete directory path of a filename (including hashedDirectoryStructure)
      *
      * @param  string $id Cache id
+     * @param  boolean $parts if true, returns array of directory parts instead of single string
      * @return string Complete directory path
      */
-    private function _path($id)
+    private function _path($id, $parts = false)
     {
+        $partsArray = array();
         $root = $this->_options['cache_dir'];
         $prefix = $this->_options['file_name_prefix'];
         if ($this->_options['hashed_directory_level']>0) {
             $hash = hash('adler32', $id);
             for ($i=0 ; $i < $this->_options['hashed_directory_level'] ; $i++) {
                 $root = $root . $prefix . '--' . substr($hash, 0, $i + 1) . DIRECTORY_SEPARATOR;
+                $partsArray[] = $root;
             }
         }
-        return $root;
+        if ($parts) {
+            return $partsArray;
+        } else {
+            return $root;
+        }
     }
     
+    /**
+     * Make the directory strucuture for the given id
+     * 
+     * @param string $id cache id
+     * @return boolean true
+     */
+    private function _recursiveMkdirAndChmod($id)
+    {
+        if ($this->_options['hashed_directory_level'] <=0) {
+            return true;
+        }
+        $partsArray = $this->_path($id, true);
+        foreach ($partsArray as $part) {
+        	if (!is_dir($part)) {
+            	@mkdir($part, $this->_options['hashed_directory_umask']);
+        	    @chmod($part, $this->_options['hashed_directory_umask']); // see #ZF-320 (this line is required in some configurations)         
+        	}
+        }
+        return true;
+    }
+   
     /**
      * Test if the given cache id is available (and still valid as a cache record)
      *
@@ -641,15 +928,15 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         if (!$metadatas) {
             return false;
         }
-        if ($doNotTestCacheValidity || (time() <= $metadatas['expire'])) { 
+        if ($doNotTestCacheValidity || (time() <= $metadatas['expire'])) {
             return $metadatas['mtime'];
         }
         return false;
     }
-    
+
     /**
      * Return the file content of the given file
-     * 
+     *
      * @param  string $file File complete path
      * @return string File content (or false if problem)
      */
@@ -659,48 +946,48 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         if (!is_file($file)) {
             return false;
         }
-        $mqr = get_magic_quotes_runtime();
-        set_magic_quotes_runtime(0);       
+        if (function_exists('get_magic_quotes_runtime')) {
+            $mqr = @get_magic_quotes_runtime();
+            @set_magic_quotes_runtime(0);
+        }
         $f = @fopen($file, 'rb');
         if ($f) {
             if ($this->_options['file_locking']) @flock($f, LOCK_SH);
-            $fsize = @filesize($file);
-            if ($fsize == 0) {
-                $result = '';
-            } else {
-                $result = fread($f, $fsize);
-            }
+            $result = stream_get_contents($f);
             if ($this->_options['file_locking']) @flock($f, LOCK_UN);
             @fclose($f);
         }
-        set_magic_quotes_runtime($mqr);
+        if (function_exists('set_magic_quotes_runtime')) {
+            @set_magic_quotes_runtime($mqr);
+        }
         return $result;
     }
-    
+
     /**
      * Put the given string into the given file
-     * 
+     *
      * @param  string $file   File complete path
      * @param  string $string String to put in file
      * @return boolean true if no problem
-     */    
+     */
     private function _filePutContents($file, $string)
     {
-        $result = false;   
-        $f = @fopen($file, 'wb');
+        $result = false;
+        $f = @fopen($file, 'ab+');
         if ($f) {
             if ($this->_options['file_locking']) @flock($f, LOCK_EX);
+            fseek($f, 0);
+            ftruncate($f, 0);
             $tmp = @fwrite($f, $string);
             if (!($tmp === FALSE)) {
                 $result = true;
-            }    
-            if ($this->_options['file_locking']) @flock($f, LOCK_UN);
+            }
             @fclose($f);
         }
         @chmod($file, $this->_options['cache_file_umask']);
         return $result;
     }
-    
+
     /**
      * Transform a file name into cache id and return it
      *
@@ -712,5 +999,5 @@ class Zend_Cache_Backend_File extends Zend_Cache_Backend implements Zend_Cache_B
         $prefix = $this->_options['file_name_prefix'];
         return preg_replace('~^' . $prefix . '---(.*)$~', '$1', $fileName);
     }
-    
+
 }
