@@ -16,8 +16,8 @@
  * @category   Zend
  * @package    Zend_Console_Getopt
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
- * @version    $Id$
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: $
  */
 
 /**
@@ -265,7 +265,7 @@ class Zend_Console_Getopt
      * @param  string $key
      * @return string
      */
-    protected function __get($key)
+    public function __get($key)
     {
         return $this->getOption($key);
     }
@@ -276,7 +276,7 @@ class Zend_Console_Getopt
      * @param  string $key
      * @return boolean
      */
-    protected function __isset($key)
+    public function __isset($key)
     {
         $this->parse();
         if (isset($this->_ruleMap[$key])) {
@@ -293,7 +293,7 @@ class Zend_Console_Getopt
      * @param  string $value
      * @return void
      */
-    protected function __set($key, $value)
+    public function __set($key, $value)
     {
         $this->parse();
         if (isset($this->_ruleMap[$key])) {
@@ -406,7 +406,6 @@ class Zend_Console_Getopt
                     $this->_addRulesModeZend($rules);
                     break;
                 }
-                $this->_getoptConfig['ruleMode'] = self::MODE_GNU;
                 // intentional fallthrough
             case self::MODE_GNU:
                 $this->_addRulesModeGnu($rules);
@@ -692,7 +691,7 @@ class Zend_Console_Getopt
             }
             if (substr($argv[0], 0, 2) == '--') {
                 $this->_parseLongOption($argv);
-            } else if (substr($argv[0], 0, 1) == '-') {
+            } else if (substr($argv[0], 0, 1) == '-' && ('-' != $argv[0] || count($argv) >1))  {
                 $this->_parseShortOptionCluster($argv);
             } else {
                 $this->_remainingArgs[] = array_shift($argv);
@@ -713,7 +712,7 @@ class Zend_Console_Getopt
     protected function _parseLongOption(&$argv)
     {
         $optionWithParam = ltrim(array_shift($argv), '-');
-        $l = explode('=', $optionWithParam);
+        $l = explode('=', $optionWithParam, 2);
         $flag = array_shift($l);
         $param = array_shift($l);
         if (isset($param)) {
@@ -841,7 +840,7 @@ class Zend_Console_Getopt
     protected function _addRulesModeGnu($rules)
     {
         $ruleArray = array();
-
+        
         /**
          * Options may be single alphanumeric characters.
          * Options may have a ':' which indicates a required string parameter.
@@ -877,11 +876,17 @@ class Zend_Console_Getopt
     {
         foreach ($rules as $ruleCode => $helpMessage)
         {
-            $tokens = preg_split('/([=-])/',
-                $ruleCode, 2, PREG_SPLIT_DELIM_CAPTURE);
-            $flagList = array_shift($tokens);
-            $delimiter = array_shift($tokens);
-            $paramType = array_shift($tokens);
+            // this may have to translate the long parm type if there
+            // are any complaints that =string will not work (even though that use
+            // case is not documented) 
+            if (in_array(substr($ruleCode, -2, 1), array('-', '='))) {
+                $flagList  = substr($ruleCode, 0, -2);
+                $delimiter = substr($ruleCode, -2, 1);
+                $paramType = substr($ruleCode, -1);
+            } else {
+                $flagList = $ruleCode;
+                $delimiter = $paramType = null;
+            }
             if ($this->_getoptConfig[self::CONFIG_IGNORECASE]) {
                 $flagList = strtolower($flagList);
             }
