@@ -4,13 +4,13 @@
  *
  * LICENSE
  *
- * This source file is subject to version 1.0 of the Zend Framework
- * license, that is bundled with this package in the file LICENSE.txt, and
- * is available through the world-wide-web at the following URL:
- * http://framework.zend.com/license/new-bsd. If you did not receive
- * a copy of the Zend Framework license and are unable to obtain it
- * through the world-wide-web, please send a note to license@zend.com
- * so we can mail you a copy immediately.
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
  *
  * @package    Zend_Db
  * @subpackage Adapter
@@ -29,6 +29,11 @@ require_once 'Zend/Db.php';
  */
 require_once 'Zend/Db/Adapter/Abstract.php';
 
+/**
+ * @see Zend_Loader
+ */
+require_once 'Zend/Loader.php';
+
 /**
  * @see Zend_Db_Statement_Db2
  */
@@ -39,8 +44,6 @@ require_once 'Zend/Db/Statement/Db2.php';
  * @package    Zend_Db
  * @copyright  Copyright (c) 2005-2008 Zend Technologies Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @author     Joscha Feth <jffeth@de.ibm.com>
- * @author     Salvador Ledezma <ledezma@us.ibm.com>
  */
 
 class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
@@ -57,6 +60,8 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
      * protocol   => (string)  Protocol to use, defaults to "TCPIP"
      * port       => (integer) Port number to use for TCP/IP if protocol is "TCPIP"
      * persistent => (boolean) Set TRUE to use a persistent connection (db2_pconnect)
+     * os         => (string)  This should be set to 'i5' if the db is on an os400/i5
+     * schema     => (string)  The default schema the connection should use
      *
      * @var array
      */
@@ -67,7 +72,9 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
         'host'         => 'localhost',
         'port'         => '50000',
         'protocol'     => 'TCPIP',
-        'persistent'   => false
+        'persistent'   => false,
+        'os'           => null,
+        'schema'       => null
     );
 
     /**
@@ -77,6 +84,14 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
      */
     protected $_execute_mode = DB2_AUTOCOMMIT_ON;
 
+    /**
+     * Default class name for a DB statement.
+     *
+     * @var string
+     */
+    protected $_defaultStmtClass = 'Zend_Db_Statement_Db2';
+    protected $_isI5 = false;
+
     /**
      * Keys are UPPERCASE SQL datatypes or the constants
      * Zend_Db::INT_TYPE, Zend_Db::BIGINT_TYPE, or Zend_Db::FLOAT_TYPE.
@@ -119,6 +134,7 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
             throw new Zend_Db_Adapter_Db2_Exception('The IBM DB2 extension is required for this adapter but the extension is not loaded');
         }
 
+        $this->_determineI5();
         if ($this->_config['persistent']) {
             // use persistent connection
             $conn_func_name = 'db2_pconnect';
@@ -141,7 +157,7 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
             $this->_config['driver_options']['DB2_ATTR_CASE'] = $caseAttrMap[$this->_config['options'][Zend_Db::CASE_FOLDING]];
         }
 
-        if ($this->_config['host'] !== 'localhost') {
+        if ($this->_config['host'] !== 'localhost' && !$this->_isI5) {
             // if the host isn't localhost, use extended connection params
             $dbname = 'DRIVER={IBM DB2 ODBC DRIVER}' .
                      ';DATABASE=' . $this->_config['dbname'] .
@@ -176,6 +192,17 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
         }
     }
 
+    /**
+     * Test if a connection is active
+     *
+     * @return boolean
+     */
+    public function isConnected()
+    {
+        return ((bool) (is_resource($this->_connection)
+                     && get_resource_type($this->_connection) == 'DB2 Connection'));
+    }
+
     /**
      * Force the connection to close.
      *
@@ -183,7 +210,9 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
      */
     public function closeConnection()
     {
-        db2_close($this->_connection);
+        if ($this->isConnected()) {
+            db2_close($this->_connection);
+        }
         $this->_connection = null;
     }
 
@@ -196,7 +225,9 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
     public function prepare($sql)
     {
         $this->_connect();
-        $stmt = new Zend_Db_Statement_Db2($this, $sql);
+        $stmtClass = $this->_defaultStmtClass;
+        Zend_Loader::loadClass($stmtClass);
+        $stmt = new $stmtClass($this, $sql);
         $stmt->setFetchMode($this->_fetchMode);
         return $stmt;
     }
@@ -262,32 +293,49 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
     {
         $this->_connect();
         $info = db2_server_info($this->_connection);
-        $identQuote = $info->IDENTIFIER_QUOTE_CHAR;
+        if ($info) {
+            $identQuote = $info->IDENTIFIER_QUOTE_CHAR;
+        } else {
+            // db2_server_info() does not return result on some i5 OS version
+            if ($this->_isI5) {
+                $identQuote ="'";
+            }
+        }
         return $identQuote;
     }
 
     /**
      * Returns a list of the tables in the database.
-     *
+     * @param string $schema OPTIONAL
      * @return array
      */
-    public function listTables()
+    public function listTables($schema = null)
     {
         $this->_connect();
 
-        // take the most general case and assume no z/OS
-        // since listTables() takes no parameters
-        $stmt = db2_tables($this->_connection);
+        if ($schema === null && $this->_config['schema'] != null) {
+            $schema = $this->_config['schema'];
+        }
 
         $tables = array();
 
-        while ($row = db2_fetch_assoc($stmt)) {
-            $tables[] = $row['TABLE_NAME'];
+        if (!$this->_isI5) {
+            if ($schema) {
+                $stmt = db2_tables($this->_connection, null, $schema);
+            } else {
+                $stmt = db2_tables($this->_connection);
+            }
+            while ($row = db2_fetch_assoc($stmt)) {
+                $tables[] = $row['TABLE_NAME'];
+            }
+        } else {
+            $tables = $this->_i5listTables($schema);
         }
 
         return $tables;
     }
 
+
     /**
      * Returns the column descriptions for a table.
      *
@@ -308,35 +356,69 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
      * SCALE            => number; scale of NUMERIC/DECIMAL
      * PRECISION        => number; precision of NUMERIC/DECIMAL
      * UNSIGNED         => boolean; unsigned property of an integer type
+     *                     DB2 not supports UNSIGNED integer.
      * PRIMARY          => boolean; true if column is part of the primary key
      * PRIMARY_POSITION => integer; position of column in primary key
      * IDENTITY         => integer; true if column is auto-generated with unique values
      *
-     * @todo Discover integer unsigned property.
-     *
      * @param string $tableName
      * @param string $schemaName OPTIONAL
      * @return array
      */
     public function describeTable($tableName, $schemaName = null)
     {
-        $sql = "SELECT DISTINCT c.tabschema, c.tabname, c.colname, c.colno,
-              c.typename, c.default, c.nulls, c.length, c.scale,
-              c.identity, tc.type AS tabconsttype, k.colseq
-            FROM syscat.columns c
-              LEFT JOIN (syscat.keycoluse k JOIN syscat.tabconst tc
+        // Ensure the connection is made so that _isI5 is set
+        $this->_connect();
+
+        if ($schemaName === null && $this->_config['schema'] != null) {
+            $schemaName = $this->_config['schema'];
+        }
+        
+        if (!$this->_isI5) {
+
+            $sql = "SELECT DISTINCT c.tabschema, c.tabname, c.colname, c.colno,
+                c.typename, c.default, c.nulls, c.length, c.scale,
+                c.identity, tc.type AS tabconsttype, k.colseq
+                FROM syscat.columns c
+                LEFT JOIN (syscat.keycoluse k JOIN syscat.tabconst tc
                 ON (k.tabschema = tc.tabschema
-                  AND k.tabname = tc.tabname
-                  AND tc.type = 'P'))
-              ON (c.tabschema = k.tabschema
-                AND c.tabname = k.tabname
-                AND c.colname = k.colname)
-            WHERE "
-            . $this->quoteInto('UPPER(c.tabname) = UPPER(?)', $tableName);
-        if ($schemaName) {
-            $sql .= $this->quoteInto(' AND UPPER(c.tabschema) = UPPER(?)', $schemaName);
+                    AND k.tabname = tc.tabname
+                    AND tc.type = 'P'))
+                ON (c.tabschema = k.tabschema
+                    AND c.tabname = k.tabname
+                    AND c.colname = k.colname)
+                WHERE "
+                . $this->quoteInto('UPPER(c.tabname) = UPPER(?)', $tableName);
+
+            if ($schemaName) {
+               $sql .= $this->quoteInto(' AND UPPER(c.tabschema) = UPPER(?)', $schemaName);
+            }
+
+            $sql .= " ORDER BY c.colno";
+
+        } else {
+
+            // DB2 On I5 specific query
+            $sql = "SELECT DISTINCT C.TABLE_SCHEMA, C.TABLE_NAME, C.COLUMN_NAME, C.ORDINAL_POSITION,
+                C.DATA_TYPE, C.COLUMN_DEFAULT, C.NULLS ,C.LENGTH, C.SCALE, LEFT(C.IDENTITY,1),
+                LEFT(tc.TYPE, 1) AS tabconsttype, k.COLSEQ
+                FROM QSYS2.SYSCOLUMNS C
+                LEFT JOIN (QSYS2.syskeycst k JOIN QSYS2.SYSCST tc
+                    ON (k.TABLE_SCHEMA = tc.TABLE_SCHEMA
+                      AND k.TABLE_NAME = tc.TABLE_NAME
+                      AND LEFT(tc.type,1) = 'P'))                  
+                    ON (C.TABLE_SCHEMA = k.TABLE_SCHEMA
+                       AND C.TABLE_NAME = k.TABLE_NAME
+                       AND C.COLUMN_NAME = k.COLUMN_NAME)                          
+                WHERE "
+                 . $this->quoteInto('UPPER(C.TABLE_NAME) = UPPER(?)', $tableName);
+
+            if ($schemaName) {
+                $sql .= $this->quoteInto(' AND UPPER(C.TABLE_SCHEMA) = UPPER(?)', $schemaName);
+            }
+
+            $sql .= " ORDER BY C.ORDINAL_POSITION FOR FETCH ONLY";
         }
-        $sql .= " ORDER BY c.colno";
 
         $desc = array();
         $stmt = $this->query($sql);
@@ -360,12 +442,12 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
         $length         = 7;
         $scale          = 8;
         $identityCol    = 9;
-        $tabconstype    = 10;
+        $tabconstType   = 10;
         $colseq         = 11;
 
         foreach ($result as $key => $row) {
             list ($primary, $primaryPosition, $identity) = array(false, null, false);
-            if ($row[$tabconstype] == 'P') {
+            if ($row[$tabconstType] == 'P') {
                 $primary = true;
                 $primaryPosition = $row[$colseq];
             }
@@ -382,14 +464,14 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
                 'SCHEMA_NAME'      => $this->foldCase($row[$tabschema]),
                 'TABLE_NAME'       => $this->foldCase($row[$tabname]),
                 'COLUMN_NAME'      => $this->foldCase($row[$colname]),
-                'COLUMN_POSITION'  => $row[$colno]+1,
+                'COLUMN_POSITION'  => (!$this->_isI5) ? $row[$colno]+1 : $row[$colno],
                 'DATA_TYPE'        => $row[$typename],
                 'DEFAULT'          => $row[$default],
                 'NULLABLE'         => (bool) ($row[$nulls] == 'Y'),
                 'LENGTH'           => $row[$length],
                 'SCALE'            => $row[$scale],
                 'PRECISION'        => ($row[$typename] == 'DECIMAL' ? $row[$length] : 0),
-                'UNSIGNED'         => null, // @todo
+                'UNSIGNED'         => false,
                 'PRIMARY'          => $primary,
                 'PRIMARY_POSITION' => $primaryPosition,
                 'IDENTITY'         => $identity
@@ -410,7 +492,15 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
     public function lastSequenceId($sequenceName)
     {
         $this->_connect();
-        $sql = 'SELECT PREVVAL FOR '.$this->quoteIdentifier($sequenceName, true).' AS VAL FROM SYSIBM.SYSDUMMY1';
+
+        if (!$this->_isI5) {
+            $quotedSequenceName = $this->quoteIdentifier($sequenceName, true);
+            $sql = 'SELECT PREVVAL FOR ' . $quotedSequenceName . ' AS VAL FROM SYSIBM.SYSDUMMY1';
+        } else {
+            $quotedSequenceName = $sequenceName;
+            $sql = 'SELECT PREVVAL FOR ' . $this->quoteIdentifier($sequenceName, true) . ' AS VAL FROM QSYS2.QSQPTABL';
+        }
+
         $value = $this->fetchOne($sql);
         return (string) $value;
     }
@@ -446,12 +536,18 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
      *
      * @param string $tableName OPTIONAL
      * @param string $primaryKey OPTIONAL
+     * @param string $idType OPTIONAL used for i5 platform to define sequence/idenity unique value
      * @return string
      */
-    public function lastInsertId($tableName = null, $primaryKey = null)
+
+    public function lastInsertId($tableName = null, $primaryKey = null, $idType = null)
     {
         $this->_connect();
 
+        if ($this->_isI5) {
+            return (string) $this->_i5LastInsertId($tableName, $idType);
+        }
+
         if ($tableName !== null) {
             $sequenceName = $tableName;
             if ($primaryKey) {
@@ -606,13 +702,131 @@ class Zend_Db_Adapter_Db2 extends Zend_Db_Adapter_Abstract
      */
     public function supportsParameters($type)
     {
-        switch ($type) {
-            case 'positional':
-                return true;
-            case 'named':
-            default:
-                return false;
+        if ($type == 'positional') {
+            return true;
+        }
+
+        // if its 'named' or anything else
+        return false;
+    }
+
+    /**
+     * Retrieve server version in PHP style
+     *
+     * @return string
+     */
+    public function getServerVersion()
+    {
+        $this->_connect();
+        $server_info = db2_server_info($this->_connection);
+        if ($server_info !== false) {
+            $version = $server_info->DBMS_VER;
+            if ($this->_isI5) {
+                $version = (int) substr($version, 0, 2) . '.' . (int) substr($version, 2, 2) . '.' . (int) substr($version, 4);
+            }
+            return $version;
+        } else {
+            return null;
         }
     }
 
+    /**
+     * Return whether or not this is running on i5
+     *
+     * @return bool
+     */
+    public function isI5()
+    {
+        if ($this->_isI5 === null) {
+            $this->_determineI5();
+        }
+
+        return (bool) $this->_isI5;
+    }
+
+    /**
+     * Check the connection parameters according to verify
+     * type of used OS
+     *
+     *  @return void
+     */
+    protected function _determineI5()
+    {
+        // first us the compiled flag.
+        $this->_isI5 = (php_uname('s') == 'OS400') ? true : false;
+
+        // if this is set, then us it
+        if (isset($this->_config['os'])){
+            if (strtolower($this->_config['os']) === 'i5') {
+                $this->_isI5 = true;
+            } else {
+                // any other value passed in, its null
+                $this->_isI5 = false;
+            }
+        }
+
+    }
+
+    /**
+     * Db2 On I5 specific method
+     *
+     * Returns a list of the tables in the database .
+     * Used only for DB2/400.
+     *
+     * @return array
+     */
+    protected function _i5listTables($schema = null)
+    {
+        //list of i5 libraries.
+        $tables = array();
+        if ($schema) {
+            $tablesStatement = db2_tables($this->_connection, null, $schema);
+            while ($rowTables = db2_fetch_assoc($tablesStatement) ) {
+                if ($rowTables['TABLE_NAME'] !== null) {
+                    $tables[] = $rowTables['TABLE_NAME'];
+                }
+            }
+        } else {
+            $schemaStatement = db2_tables($this->_connection);
+            while ($schema = db2_fetch_assoc($schemaStatement)) {
+                if ($schema['TABLE_SCHEM'] !== null) {
+                    // list of the tables which belongs to the selected library
+                    $tablesStatement = db2_tables($this->_connection, NULL, $schema['TABLE_SCHEM']);
+                    if (is_resource($tablesStatement)) {
+                        while ($rowTables = db2_fetch_assoc($tablesStatement) ) {
+                            if ($rowTables['TABLE_NAME'] !== null) {
+                                $tables[] = $rowTables['TABLE_NAME'];
+                            }
+                        }
+                    }
+                }
+            }
+        }
+
+        return $tables;
+    }
+
+    protected function _i5LastInsertId($objectName = null, $idType = null)
+    {
+
+        if ($objectName === null) {
+            $sql = 'SELECT IDENTITY_VAL_LOCAL() AS VAL FROM QSYS2.QSQPTABL';
+            $value = $this->fetchOne($sql);
+            return $value;
+        }
+
+        if (strtoupper($idType) === 'S'){
+            //check i5_lib option
+            $sequenceName = $objectName;
+            return $this->lastSequenceId($sequenceName);
+        }
+
+            //returns last identity value for the specified table
+        //if (strtoupper($idType) === 'I') {
+        $tableName = $objectName;
+        return $this->fetchOne('SELECT IDENTITY_VAL_LOCAL() from ' . $this->quoteIdentifier($tableName));
+    }
+
 }
+
+
