@@ -47,6 +47,7 @@ class Zend_Db_Select
     const DISTINCT       = 'distinct';
     const COLUMNS        = 'columns';
     const FROM           = 'from';
+    const UNION          = 'union';
     const WHERE          = 'where';
     const GROUP          = 'group';
     const HAVING         = 'having';
@@ -64,6 +65,8 @@ class Zend_Db_Select
 
     const SQL_WILDCARD   = '*';
     const SQL_SELECT     = 'SELECT';
+    const SQL_UNION      = 'UNION';
+    const SQL_UNION_ALL  = 'UNION ALL';
     const SQL_FROM       = 'FROM';
     const SQL_WHERE      = 'WHERE';
     const SQL_DISTINCT   = 'DISTINCT';
@@ -95,6 +98,7 @@ class Zend_Db_Select
     protected static $_partsInit = array(
         self::DISTINCT     => false,
         self::COLUMNS      => array(),
+        self::UNION        => array(),
         self::FROM         => array(),
         self::WHERE        => array(),
         self::GROUP        => array(),
@@ -106,7 +110,7 @@ class Zend_Db_Select
     );
 
     /**
-     * The initial values for the $_parts array.
+     * Specify legal join types.
      *
      * @var array
      */
@@ -119,6 +123,16 @@ class Zend_Db_Select
         self::NATURAL_JOIN,
     );
 
+    /**
+     * Specify legal union types.
+     *
+     * @var array
+     */
+    protected static $_unionTypes = array(
+        self::SQL_UNION,
+        self::SQL_UNION_ALL
+    );
+
     /**
      * The component parts of a SELECT statement.
      * Initialized to the $_partsInit array in the constructor.
@@ -186,6 +200,62 @@ class Zend_Db_Select
         return $this->joinInner($name, null, $cols, $schema);
     }
 
+    /**
+     * Specifies the columns used in the FROM clause.
+     *
+     * The parameter can be a single string or Zend_Db_Expr object,
+     * or else an array of strings or Zend_Db_Expr objects.
+     *
+     * @param  array|string|Zend_Db_Expr $cols The columns to select from this table.
+     * @param  string $correlationName Correlation name of target table. OPTIONAL
+     * @return Zend_Db_Select This Zend_Db_Select object.
+     */
+    public function columns($cols = '*', $correlationName = null)
+    {
+        if ($correlationName === null && count($this->_parts[self::FROM])) {
+            $correlationName = current(array_keys($this->_parts[self::FROM]));
+        }
+
+        if (!array_key_exists($correlationName, $this->_parts[self::FROM])) {
+            /**
+             * @see Zend_Db_Select_Exception
+             */
+            require_once 'Zend/Db/Select/Exception.php';
+            throw new Zend_Db_Select_Exception("No table has been specified for the FROM clause");
+        }
+
+        $this->_tableCols($correlationName, $cols);
+
+        return $this;
+    }
+
+    /**
+     * Adds a UNION clause to the query.
+     *
+     * The first parameter $select can be a string, an existing Zend_Db_Select
+     * object or an array of either of these types.
+     *
+     * @param  array|string|Zend_Db_Select $select One or more select clauses for the UNION.
+     * @return Zend_Db_Select This Zend_Db_Select object.
+     */
+    public function union($select = array(), $type = self::SQL_UNION)
+    {
+        if (!is_array($select)) {
+            $select = array();
+        }
+
+        if (!in_array($type, self::$_unionTypes)) {
+            require_once 'Zend/Db/Select/Exception.php';
+            throw new Zend_Db_Select_Exception("Invalid union type '{$type}'");
+        }
+
+        foreach ($select as $target) {
+            $this->_parts[self::UNION][] = array($target, $type);
+        }
+
+        return $this;
+    }
+
     /**
      * Adds a JOIN table and columns to the query.
      *
@@ -574,6 +644,23 @@ class Zend_Db_Select
         return $stmt;
     }
 
+    /**
+     * Converts this object to an SQL SELECT string.
+     *
+     * @return string This object as a SELECT string.
+     */
+    public function assemble()
+    {
+        $sql = self::SQL_SELECT;
+        foreach (array_keys(self::$_partsInit) as $part) {
+            $method = '_render' . ucfirst($part);
+            if (method_exists($this, $method)) {
+                $sql = $this->$method($sql);
+            }
+        }
+        return $sql;
+    }
+
     /**
      * Clear parts of the Select object, or an individual part.
      *
@@ -590,6 +677,17 @@ class Zend_Db_Select
         return $this;
     }
 
+    /**
+     * Gets the Zend_Db_Adapter_Abstract for this
+     * particular Zend_Db_Select object.
+     *
+     * @return Zend_Db_Adapter_Abstract
+     */
+    public function getAdapter()
+    {
+        return $this->_adapter;
+    }
+
     /**
      * Populate the {@link $_parts} 'join' key
      *
@@ -616,6 +714,11 @@ class Zend_Db_Select
             throw new Zend_Db_Select_Exception("Invalid join type '$type'");
         }
 
+        if (count($this->_parts[self::UNION])) {
+            require_once 'Zend/Db/Select/Exception.php';
+            throw new Zend_Db_Select_Exception("Invalid use of table with " . self::SQL_UNION);
+        }
+
         if (empty($name)) {
             $correlationName = $tableName = '';
         } else if (is_array($name)) {
@@ -703,8 +806,8 @@ class Zend_Db_Select
             throw new Zend_Db_Select_Exception("You can only perform a joinUsing after specifying a FROM table");
         }
 
-        $join  = $this->_adapter->quoteIdentifier(key($this->_parts[self::FROM]));
-        $from  = $this->_adapter->quoteIdentifier($this->_uniqueCorrelation($name));
+        $join  = $this->_adapter->quoteIdentifier(key($this->_parts[self::FROM]), true);
+        $from  = $this->_adapter->quoteIdentifier($this->_uniqueCorrelation($name), true);
 
         $cond1 = $from . '.' . $cond;
         $cond2 = $join . '.' . $cond;
@@ -747,11 +850,12 @@ class Zend_Db_Select
         if (!is_array($cols)) {
             $cols = array($cols);
         }
+
         if ($correlationName == null) {
             $correlationName = '';
         }
 
-        foreach ($cols as $alias => $col) {
+        foreach (array_filter($cols) as $alias => $col) {
             $currentCorrelationName = $correlationName;
             if (is_string($col)) {
                 // Check for a column matching "<column> AS <alias>" and extract the alias name
@@ -782,6 +886,11 @@ class Zend_Db_Select
      */
     protected function _where($condition, $value = null, $type = null, $bool = true)
     {
+        if (count($this->_parts[self::UNION])) {
+            require_once 'Zend/Db/Select/Exception.php';
+            throw new Zend_Db_Select_Exception("Invalid use of where clause with " . self::SQL_UNION);
+        }
+
         if ($value !== null) {
             $condition = $this->_adapter->quoteInto($condition, $value, $type);
         }
@@ -794,7 +903,7 @@ class Zend_Db_Select
                 $cond = self::SQL_OR . ' ';
             }
         }
-        
+
         return $cond . "($condition)";
     }
 
@@ -926,6 +1035,31 @@ class Zend_Db_Select
         return $sql;
     }
 
+    /**
+     * Render UNION query
+     *
+     * @param string   $sql SQL query
+     * @return string
+     */
+    protected function _renderUnion($sql)
+    {
+        if ($this->_parts[self::UNION]) {
+            $parts = count($this->_parts[self::UNION]);
+            foreach ($this->_parts[self::UNION] as $cnt => $union) {
+                list($target, $type) = $union;
+                if ($target instanceof Zend_Db_Select) {
+                    $target = $target->assemble();
+                }
+                $sql .= $target;
+                if ($cnt < $parts - 1) {
+                    $sql .= ' ' . $type . ' ';
+                }
+            }
+        }
+
+        return $sql;
+    }
+
     /**
      * Render WHERE clause
      *
@@ -1087,18 +1221,17 @@ class Zend_Db_Select
     }
 
     /**
-     * Converts this object to an SQL SELECT string.
+     * Implements magic method.
      *
      * @return string This object as a SELECT string.
      */
     public function __toString()
     {
-        $sql = self::SQL_SELECT;
-        foreach (array_keys(self::$_partsInit) as $part) {
-            $method = '_render' . ucfirst($part);
-            if (method_exists($this, $method)) {
-                $sql = $this->$method($sql);
-            }
+        try {
+            $sql = $this->assemble();
+        } catch (Exception $e) {
+            trigger_error($e->getMessage(), E_USER_WARNING);
+            $sql = '';
         }
         return $sql;
     }
