@@ -15,6 +15,7 @@
  *
  * @category   Zend
  * @package    Zend_Gdata
+ * @subpackage Photos
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
@@ -35,104 +36,105 @@ require_once 'Zend/Gdata/Feed.php';
 require_once 'Zend/Gdata/Photos/PhotoEntry.php';
 
 /**
- * Data model for a collection of photo entries, usually 
+ * Data model for a collection of photo entries, usually
  * provided by the Picasa servers.
- * 
+ *
  * For information on requesting this feed from a server, see the
  * service class, Zend_Gdata_Photos.
  *
  * @category   Zend
  * @package    Zend_Gdata
+ * @subpackage Photos
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Gdata_Photos_PhotoFeed extends Zend_Gdata_Feed
 {
-    
+
     /**
      * gphoto:id element
      *
      * @var Zend_Gdata_Photos_Extension_Id
      */
     protected $_gphotoId = null;
-    
+
     /**
      * gphoto:albumid element
      *
      * @var Zend_Gdata_Photos_Extension_AlbumId
      */
     protected $_gphotoAlbumId = null;
-    
+
     /**
      * gphoto:version element
      *
      * @var Zend_Gdata_Photos_Extension_Version
      */
     protected $_gphotoVersion = null;
-    
+
     /**
      * gphoto:width element
      *
      * @var Zend_Gdata_Photos_Extension_Width
      */
     protected $_gphotoWidth = null;
-    
+
     /**
      * gphoto:height element
      *
      * @var Zend_Gdata_Photos_Extension_Height
      */
     protected $_gphotoHeight = null;
-    
+
     /**
      * gphoto:size element
      *
      * @var Zend_Gdata_Photos_Extension_Size
      */
     protected $_gphotoSize = null;
-    
+
     /**
      * gphoto:client element
      *
      * @var Zend_Gdata_Photos_Extension_Client
      */
     protected $_gphotoClient = null;
-    
+
     /**
      * gphoto:checksum element
      *
      * @var Zend_Gdata_Photos_Extension_Checksum
      */
     protected $_gphotoChecksum = null;
-    
+
     /**
      * gphoto:timestamp element
      *
      * @var Zend_Gdata_Photos_Extension_Timestamp
      */
     protected $_gphotoTimestamp = null;
-    
+
     /**
      * gphoto:commentCount element
      *
      * @var Zend_Gdata_Photos_Extension_CommentCount
      */
     protected $_gphotoCommentCount = null;
-    
+
     /**
      * gphoto:commentingEnabled element
      *
      * @var Zend_Gdata_Photos_Extension_CommentingEnabled
      */
     protected $_gphotoCommentingEnabled = null;
-    
+
     /**
      * media:group element
      *
      * @var Zend_Gdata_Media_Extension_MediaGroup
      */
     protected $_mediaGroup = null;
-    
+
     protected $_entryClassName = 'Zend_Gdata_Photos_PhotoEntry';
     protected $_feedClassName = 'Zend_Gdata_Photos_PhotoFeed';
 
@@ -143,15 +145,13 @@ class Zend_Gdata_Photos_PhotoFeed extends Zend_Gdata_Feed
 
     public function __construct($element = null)
     {
-        foreach (Zend_Gdata_Photos::$namespaces as $nsPrefix => $nsUri) {
-            $this->registerNamespace($nsPrefix, $nsUri);
-        }
+        $this->registerAllNamespaces(Zend_Gdata_Photos::$namespaces);
         parent::__construct($element);
     }
 
-    public function getDOM($doc = null)
+    public function getDOM($doc = null, $majorVersion = 1, $minorVersion = null)
     {
-        $element = parent::getDOM($doc);
+        $element = parent::getDOM($doc, $majorVersion, $minorVersion);
         if ($this->_gphotoId != null) {
             $element->appendChild($this->_gphotoId->getDOM($element->ownerDocument));
         }
@@ -249,7 +249,7 @@ class Zend_Gdata_Photos_PhotoFeed extends Zend_Gdata_Feed
                 $commentCount->transferFromDOM($child);
                 $this->_gphotoCommentCount = $commentCount;
                 break;
-            case $this->lookupNamespace('media') . ':' . 'group'; 
+            case $this->lookupNamespace('media') . ':' . 'group';
                 $mediaGroup = new Zend_Gdata_Media_Extension_MediaGroup();
                 $mediaGroup->transferFromDOM($child);
                 $this->_mediaGroup = $mediaGroup;
@@ -508,7 +508,7 @@ class Zend_Gdata_Photos_PhotoFeed extends Zend_Gdata_Feed
         $this->_gphotoCommentCount = $value;
         return $this;
     }
-    
+
     /**
      * Get the value for this element's gphoto:commentingEnabled attribute.
      *
@@ -531,7 +531,7 @@ class Zend_Gdata_Photos_PhotoFeed extends Zend_Gdata_Feed
         $this->_gphotoCommentingEnabled = $value;
         return $this;
     }
-    
+
     /**
      * Get the value for this element's media:group attribute.
      *
