@@ -18,7 +18,7 @@
  * @subpackage Zend_OpenId_Provider
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Provider.php 10106 2008-07-15 16:58:38Z dmitry $
+ * @version    $Id: Provider.php 12507 2008-11-10 16:29:09Z matthew $
  */
 
 /**
@@ -78,6 +78,13 @@ class Zend_OpenId_Provider
      */
     private $_trustUrl;
 
+    /**
+     * The OP Endpoint URL
+     *
+     * @var string $_opEndpoint
+     */
+    private $_opEndpoint;
+
     /**
      * Constructs a Zend_OpenId_Provider object with given parameters.
      *
@@ -130,6 +137,17 @@ class Zend_OpenId_Provider
         $this->_sessionTtl = $sessionTtl;
     }
 
+    /**
+     * Sets the OP Endpoint URL
+     *
+     * @param string $url the OP Endpoint URL
+     * @return null
+     */
+    public function setOpEndpoint($url)
+    {
+        $this->_opEndpoint = $url;
+    }
+
     /**
      * Registers a new user with given $id and $password
      * Returns true in case of success and false if user with given $id already
@@ -528,7 +546,7 @@ class Zend_OpenId_Provider
             }
             if ($immediate) {
                 $params2['openid.mode'] = 'checkid_setup';
-                $ret['openid.mode'] = ($version >= 2.0) ? 'setup_needed': 'cancel';
+                $ret['openid.mode'] = ($version >= 2.0) ? 'setup_needed': 'id_res';
                 $ret['openid.user_setup_url'] = $this->_loginUrl
                     . (strpos($this->_loginUrl, '?') === false ? '?' : '&')
                     . Zend_OpenId::paramsToQuery($params2);
@@ -600,7 +618,7 @@ class Zend_OpenId_Provider
             }
             if ($immediate) {
                 $params2['openid.mode'] = 'checkid_setup';
-                $ret['openid.mode'] = ($version >= 2.0) ? 'setup_needed': 'cancel';
+                $ret['openid.mode'] = ($version >= 2.0) ? 'setup_needed': 'id_res';
                 $ret['openid.user_setup_url'] = $this->_trustUrl
                     . (strpos($this->_trustUrl, '?') === false ? '?' : '&')
                     . Zend_OpenId::paramsToQuery($params2);
@@ -683,7 +701,11 @@ class Zend_OpenId_Provider
         }
 
         if ($version >= 2.0) {
-            $ret['openid.op_endpoint'] = Zend_OpenId::selfUrl();
+            if (!empty($this->_opEndpoint)) {
+                $ret['openid.op_endpoint'] = $this->_opEndpoint;
+            } else {
+                $ret['openid.op_endpoint'] = Zend_OpenId::selfUrl();
+            }
         }
         $ret['openid.response_nonce'] = gmdate('Y-m-d\TH:i:s\Z') . uniqid();
         $ret['openid.mode'] = 'id_res';
