@@ -16,7 +16,7 @@
  * @package    Zend_Session
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Namespace.php 9665 2008-06-11 07:39:26Z stas $
+ * @version    $Id: Namespace.php 13338 2008-12-17 11:13:16Z sidhighwind $
  * @since      Preview Release 0.2
  */
 
@@ -98,6 +98,14 @@ class Zend_Session_Namespace extends Zend_Session_Abstract implements IteratorAg
             throw new Zend_Session_Exception('Session namespace must not start with an underscore.');
         }
 
+        if (preg_match('#(^[0-9])#i', $namespace[0])) {
+            /**
+             * @see Zend_Session_Exception
+             */
+            require_once 'Zend/Session/Exception.php';
+            throw new Zend_Session_Exception('Session namespace must not start with a number.');
+        }
+
         if (isset(self::$_singleInstances[$namespace])) {
             /**
              * @see Zend_Session_Exception
@@ -244,7 +252,7 @@ class Zend_Session_Namespace extends Zend_Session_Abstract implements IteratorAg
      * @param string $name - programmatic name of a key, in a <key,value> pair in the current namespace
      * @return mixed
      */
-    protected function & __get($name)
+    public function & __get($name)
     {
         if ($name === '') {
             /**
