@@ -35,17 +35,18 @@ class Zend_Translate {
     /**
      * Adapter names constants
      */
-    const AN_ARRAY   = 'array';
-    const AN_CSV     = 'csv';
-    const AN_GETTEXT = 'gettext';
-    const AN_QT      = 'qt';
-    const AN_TBX     = 'tbx';
-    const AN_TMX     = 'tmx';
-    const AN_XLIFF   = 'xliff';
-    const AN_XMLTM   = 'xmltm';
+    const AN_ARRAY   = 'Array';
+    const AN_CSV     = 'Csv';
+    const AN_GETTEXT = 'Gettext';
+    const AN_INI     = 'Ini';
+    const AN_QT      = 'Qt';
+    const AN_TBX     = 'Tbx';
+    const AN_TMX     = 'Tmx';
+    const AN_XLIFF   = 'Xliff';
+    const AN_XMLTM   = 'XmlTm';
 
-    const LOCALE_DIRECTORY = 1;
-    const LOCALE_FILENAME  = 2;
+    const LOCALE_DIRECTORY = 'directory';
+    const LOCALE_FILENAME  = 'filename';
 
     /**
      * Adapter
@@ -55,7 +56,6 @@ class Zend_Translate {
     private $_adapter;
     private static $_cache = null;
 
-
     /**
      * Generates the standard translation object
      *
@@ -71,7 +71,6 @@ class Zend_Translate {
         $this->setAdapter($adapter, $data, $locale, $options);
     }
 
-
     /**
      * Sets a new adapter
      *
@@ -83,31 +82,8 @@ class Zend_Translate {
      */
     public function setAdapter($adapter, $data, $locale = null, array $options = array())
     {
-        switch (strtolower($adapter)) {
-            case 'array':
-                $adapter = 'Zend_Translate_Adapter_Array';
-                break;
-            case 'csv':
-                $adapter = 'Zend_Translate_Adapter_Csv';
-                break;
-            case 'gettext':
-                $adapter = 'Zend_Translate_Adapter_Gettext';
-                break;
-            case 'qt':
-                $adapter = 'Zend_Translate_Adapter_Qt';
-                break;
-            case 'tbx':
-                $adapter = 'Zend_Translate_Adapter_Tbx';
-                break;
-            case 'tmx':
-                $adapter = 'Zend_Translate_Adapter_Tmx';
-                break;
-            case 'xliff':
-                $adapter = 'Zend_Translate_Adapter_Xliff';
-                break;
-            case 'xmltm':
-                $adapter = 'Zend_Translate_Adapter_XmlTm';
-                break;
+        if (Zend_Loader::isReadable('Zend/Translate/Adapter/' . ucfirst($adapter). '.php')) {
+            $adapter = 'Zend_Translate_Adapter_' . ucfirst($adapter);
         }
 
         Zend_Loader::loadClass($adapter);
@@ -121,7 +97,6 @@ class Zend_Translate {
         }
     }
 
-
     /**
      * Returns the adapters name and it's options
      *
@@ -132,6 +107,16 @@ class Zend_Translate {
         return $this->_adapter;
     }
 
+    /**
+     * Returns the set cache
+     *
+     * @return Zend_Cache_Core The set cache
+     */
+    public static function getCache()
+    {
+        return self::$_cache;
+    }
+
     /**
      * Sets a cache for all instances of Zend_Translate
      *
@@ -144,13 +129,37 @@ class Zend_Translate {
     }
 
     /**
-     * Returns the set cache
+     * Returns true when a cache is set
      *
-     * @return Zend_Cache_Core The set cache
+     * @return boolean
      */
-    public static function getCache()
+    public static function hasCache()
     {
-        return self::$_cache;
+        if (self::$_cache !== null) {
+            return true;
+        }
+
+        return false;
+    }
+
+    /**
+     * Removes any set cache
+     *
+     * @return void
+     */
+    public static function removeCache()
+    {
+        self::$_cache = null;
+    }
+
+    /**
+     * Clears all set cache data
+     *
+     * @return void
+     */
+    public static function clearCache()
+    {
+        self::$_cache->clean();
     }
 
     /**
