@@ -16,7 +16,7 @@
  * @package    Zend_View
  * @subpackage Helper
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
- * @version    $Id: Form.php 9363 2008-05-05 15:14:13Z matthew $
+ * @version    $Id: Form.php 10633 2008-08-04 15:19:53Z matthew $
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
@@ -33,23 +33,6 @@ require_once 'Zend/View/Helper/FormElement.php';
  */
 class Zend_View_Helper_Form extends Zend_View_Helper_FormElement
 {
-    /**
-     * @var Zend_View_Instance
-     */
-    public $view;
-
-    /**
-     * Set view object
-     * 
-     * @param  Zend_View_Interface $view 
-     * @return Zend_View_Helper_Form
-     */
-    public function setView(Zend_View_Interface $view)
-    {
-        $this->view = $view;
-        return $this;
-    }
-
     /**
      * Render HTML form
      *
@@ -65,6 +48,12 @@ class Zend_View_Helper_Form extends Zend_View_Helper_FormElement
 
         if (!empty($id)) {
             $id = ' id="' . $this->view->escape($id) . '"';
+        } else {
+            $id = '';
+        }
+
+        if (array_key_exists('id', $attribs) && empty($attribs['id'])) {
+            unset($attribs['id']);
         }
 
         $xhtml = '<form'
