@@ -17,10 +17,13 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2006 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: $
+ * @version    $Id: GetoptTest.php 13770 2009-01-24 14:24:21Z letssurf $
  */
 
-error_reporting( E_ALL | E_STRICT );
+/**
+ * Test helper
+ */
+require_once dirname(__FILE__) . '/../../TestHelper.php';
 
 /**
  * Zend_Console_Getopt
@@ -464,5 +467,82 @@ class Zend_Console_GetoptTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('string', $opts->k);
 
     }
+    
+    /**
+     * Test to ensure that dashed long names will parse correctly
+     * 
+     * @group ZF-4763
+     */
+    public function testDashWithinLongOptionGetsParsed()
+    {
+        $opts = new Zend_Console_Getopt(
+            array( // rules
+                'man-bear|m-s' => 'ManBear with dash',
+                'man-bear-pig|b=s' => 'ManBearPid with dash',
+                ),
+            array( // arguments
+                '--man-bear-pig=mbp',
+                '--man-bear',
+                'foobar'
+                )
+            );
+        
+        $opts->parse();
+        $this->assertEquals('foobar', $opts->getOption('man-bear'));
+        $this->assertEquals('mbp', $opts->getOption('man-bear-pig'));
+    }
 
+    /**
+     * @group ZF-2064
+     */
+    public function testAddRulesDoesNotThrowWarnings()
+    {
+        // Fails if warning is thrown: Should not happen!
+        $opts = new Zend_Console_Getopt('abp:');
+        $opts->addRules(
+          array(
+            'verbose|v' => 'Print verbose output'
+          )
+        );
+    }
+
+    /**
+     * @group ZF-5345
+     */
+    public function testUsingDashWithoutOptionNameAsLastArgumentIsRecognizedAsRemainingArgument()
+    {
+        $opts = new Zend_Console_Getopt("abp:", array("-"));
+        $opts->parse();
+
+        $this->assertEquals(1, count($opts->getRemainingArgs()));
+        $this->assertEquals(array("-"), $opts->getRemainingArgs());
+    }
+
+    /**
+     * @group ZF-5345
+     */
+    public function testUsingDashWithoutOptionNotAsLastArgumentThrowsException()
+    {
+        $opts = new Zend_Console_Getopt("abp:", array("-", "file1"));
+        try {
+            $opts->parse();
+            $this->fail();
+        } catch(Exception $e) {
+            $this->assertTrue($e instanceof Zend_Console_Getopt_Exception);
+        }
+    }
+    
+    /**
+     * @group ZF-5624
+     */
+    public function testEqualsCharacterInLongOptionsValue()
+    {
+        $fooValue = 'some text containing an = sign which breaks';
+
+        $opts = new Zend_Console_Getopt(
+            array('foo=s' => 'Option One (string)'),
+            array('--foo='.$fooValue)
+        );
+        $this->assertEquals($fooValue, $opts->foo);
+    }
 }
