@@ -19,11 +19,12 @@ require_once 'Zend/Controller/Response/Cli.php';
 require_once 'Zend/Json.php';
 require_once 'Zend/Layout.php';
 require_once 'Zend/View.php';
+require_once 'Zend/View/Interface.php';
 
 /**
  * Test class for Zend_Controller_Action_Helper_ContextSwitch.
  */
-class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_TestCase 
+class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Runs the test methods of this class.
@@ -67,7 +68,6 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
                     ->addControllerDirectory(dirname(__FILE__));
 
         $this->view = new Zend_View();
-        $this->view->addHelperPath(dirname(__FILE__) . '/../../../../../library/Zend/View/Helper/');
         $this->viewRenderer = Zend_Controller_Action_HelperBroker::getStaticHelper('viewRenderer');
         $this->viewRenderer->setView($this->view);
 
@@ -138,7 +138,7 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
         $this->helper->addHeader('xml', 'X-Foo', 'Bar');
         $headers = $this->helper->getHeaders('xml');
         $this->assertTrue(isset($headers['Content-Type']));
-        $this->assertEquals('text/xml', $headers['Content-Type']);
+        $this->assertEquals('application/xml', $headers['Content-Type']);
         $this->assertTrue(isset($headers['X-Foo']));
         $this->assertEquals('Bar', $headers['X-Foo']);
     }
@@ -151,7 +151,7 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
         ));
         $headers = $this->helper->getHeaders('xml');
         $this->assertTrue(isset($headers['Content-Type']));
-        $this->assertEquals('text/xml', $headers['Content-Type']);
+        $this->assertEquals('application/xml', $headers['Content-Type']);
         $this->assertTrue(isset($headers['X-Foo']));
         $this->assertEquals('Bar', $headers['X-Foo']);
         $this->assertTrue(isset($headers['X-Bar']));
@@ -195,7 +195,7 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
     public function testCanClearAllHeaders()
     {
         $this->helper->addHeader('xml', 'X-Foo', 'Bar');
-        $expected = array('Content-Type' => 'text/xml', 'X-Foo' => 'Bar');
+        $expected = array('Content-Type' => 'application/xml', 'X-Foo' => 'Bar');
         $this->assertEquals($expected, $this->helper->getHeaders('xml'));
         $this->helper->clearHeaders('xml');
         $this->assertEquals(array(), $this->helper->getHeaders('xml'));
@@ -533,7 +533,7 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
             }
         }
         $this->assertTrue($found);
-        $this->assertEquals('text/xml', $value);
+        $this->assertEquals('application/xml', $value);
     }
 
     public function testInitContextUsesPassedFormatWhenContextParamPresent()
@@ -574,7 +574,7 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
             }
         }
         $this->assertTrue($found);
-        $this->assertEquals('text/xml', $value);
+        $this->assertEquals('application/xml', $value);
     }
 
     public function testInitContextDisablesLayoutByDefault()
@@ -823,6 +823,52 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
         $this->helper = new Zend_Controller_Action_Helper_ContextSwitch($config);
         $this->checkOptionsAreSet();
     }
+
+    /**
+     * @group ZF-3279
+     */
+    public function testPostJsonContextDoesntThrowExceptionWhenGetVarsMethodsExists()
+    {
+        try {
+            $this->helper->setAutoJsonSerialization(true);
+            $this->helper->postJsonContext();
+        } catch(Zend_Controller_Action_Exception $zcae) {
+            $this->fail('Exception should be throw when view does not implement getVars() method');
+        }
+    }
+
+    /**
+     * @group ZF-3279
+     */
+    public function testPostJsonContextThrowsExceptionWhenGetVarsMethodsDoesntExist()
+    {
+        $view = new Zend_Controller_Action_Helper_ContextSwitchText_CustomView();
+        $this->viewRenderer->setView($view);
+
+        try {
+            $this->helper->setAutoJsonSerialization(true);
+            $this->helper->postJsonContext();
+            $this->fail('Exception should be throw when view does not implement getVars() method');
+        } catch(Zend_Controller_Action_Exception $zcae) {
+        }
+    }
+
+    /** 
+     * @group ZF-4866
+     */
+    public function testForwardingShouldNotUseContextSuffixIfNewActionDoesNotDetectValidContext()
+    {
+        $this->request->setParam('format', 'xml')
+                      ->setActionName('foo');
+        $this->helper->setActionContext('bar', 'json');
+        $this->helper->initContext();
+        $this->assertEquals('xml', $this->helper->getCurrentContext());
+        $this->request->setActionName('bar');
+        $this->helper->init();
+        $this->helper->initContext();
+        $suffix = $this->viewRenderer->getViewSuffix();
+        $this->assertNotContains('xml', $suffix, $suffix);
+    }
 }
 
 class Zend_Controller_Action_Helper_ContextSwitchTestController extends Zend_Controller_Action
@@ -865,6 +911,42 @@ class Zend_Controller_Action_Helper_ContextSwitchTest_LayoutOverride extends Zen
     public static $_mvcInstance;
 }
 
+class Zend_Controller_Action_Helper_ContextSwitchText_CustomView implements Zend_View_Interface
+{
+    public function getEngine()
+    {}
+
+    public function setScriptPath($path)
+    {}
+
+    public function getScriptPaths()
+    {}
+
+    public function setBasePath($path, $classPrefix = 'Zend_View')
+    {}
+
+    public function addBasePath($path, $classPrefix = 'Zend_View')
+    {}
+
+    public function __set($key, $val)
+    {}
+
+    public function __isset($key)
+    {}
+
+    public function __unset($key)
+    {}
+
+    public function assign($spec, $value = null)
+    {}
+
+    public function clearVars()
+    {}
+
+    public function render($name)
+    {}
+}
+
 // Call Zend_Controller_Action_Helper_ContextSwitchTest::main() if this source file is executed directly.
 if (PHPUnit_MAIN_METHOD == "Zend_Controller_Action_Helper_ContextSwitchTest::main") {
     Zend_Controller_Action_Helper_ContextSwitchTest::main();
