@@ -18,7 +18,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MysqlTest.php 6923 2007-11-25 02:00:06Z peptolab $
+ * @version    $Id: MysqlTest.php 12842 2008-11-25 22:07:48Z mikaelkael $
  */
 
 
@@ -239,6 +239,18 @@ class Zend_Db_Adapter_Pdo_MysqlTest extends Zend_Db_Adapter_Pdo_TestCommon
         $this->assertEquals('`table_\'_name`', $value);
     }
 
+    /**
+     * test that describeTable() returns correct types
+     * @group ZF-3624
+     * 
+     */
+    public function testAdapterDescribeTableAttributeColumnFloat()
+    {
+        $desc = $this->_db->describeTable('zfprice');
+        $this->assertEquals('zfprice',  $desc['price']['TABLE_NAME']);
+        $this->assertRegExp('/float/i', $desc['price']['DATA_TYPE']);
+    }
+
     /**
      * test that quoteTableAs() accepts a string and an alias,
      * and returns each as delimited identifiers.
@@ -263,6 +275,40 @@ class Zend_Db_Adapter_Pdo_MysqlTest extends Zend_Db_Adapter_Pdo_TestCommon
         $this->markTestIncomplete('Inconsistent test results');
     }
 
+    /**
+     * Ensures that the PDO Buffered Query does not throw the error
+     * 2014 General error
+     *
+     * @link   http://framework.zend.com/issues/browse/ZF-2101
+     * @return void
+     */
+    public function testZF2101()
+    {
+        $params = $this->_util->getParams();
+        $params['driver_options'] = array(PDO::MYSQL_ATTR_USE_BUFFERED_QUERY => true);
+        $db = Zend_Db::factory($this->getDriver(), $params);
+        
+        // Set default bound value
+        $customerId = 1;
+
+        // Stored procedure returns a single row
+        $stmt = $db->prepare('CALL zf_test_procedure(:customerId)');
+        $stmt->bindParam('customerId', $customerId, PDO::PARAM_INT);
+        $stmt->execute();
+        $result = $stmt->fetchAll();
+        $this->assertEquals(1, $result[0]['product_id']);
+
+        // Reset statement
+        $stmt->closeCursor();
+        
+        // Stored procedure returns a single row
+        $stmt = $db->prepare('CALL zf_test_procedure(:customerId)');
+        $stmt->bindParam('customerId', $customerId, PDO::PARAM_INT);
+        $stmt->execute();
+        $result = $stmt->fetchAll();
+        $this->assertEquals(1, $result[0]['product_id']);
+    }
+
     public function getDriver()
     {
         return 'Pdo_Mysql';
