@@ -18,7 +18,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 6923 2007-11-25 02:00:06Z peptolab $
+ * @version    $Id: TestCommon.php 13363 2008-12-19 06:40:31Z ralph $
  */
 
 
@@ -73,6 +73,24 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
         $db->getConnection();
     }
 
+    /**
+     * Test empty driver_options issue
+     * Case: $config['driver_options'] == ''
+     */
+    public function testAdapterZendConfigEmptyDriverOptions()
+    {
+        Zend_Loader::loadClass('Zend_Config');
+        $params = $this->_util->getParams();
+        $params['driver_options'] = '';
+        $params = new Zend_Config($params);
+
+        $db = Zend_Db::factory($this->getDriver(), $params);
+        $db->getConnection();
+
+        $config = $db->getConfig();
+        $this->assertEquals(array(), $config['driver_options']);
+    }
+
     /**
      * Test AUTO_QUOTE_IDENTIFIERS option
      * Case: Zend_Db::AUTO_QUOTE_IDENTIFIERS = true
@@ -173,6 +191,7 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
             'result of second query not as expected');
 
         // clean up
+        unset($stmt);
         $util->dropTable($tableName);
     }
 
@@ -384,6 +403,15 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(1,                   $desc['product_id']['PRIMARY_POSITION']);
     }
 
+    /**
+     * @group ZF-2927
+     */
+    public function testAdapterDescribeView()
+    {
+        $describe = $this->_db->describeTable('temp_view');
+        $this->assertEquals(8, count($describe));
+    }
+
     /**
      * Test the Adapter's fetchAll() method.
      */
@@ -1184,7 +1212,7 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
 
         $value = $this->_db->quoteInto('foo = ?', 12.34, Zend_Db::FLOAT_TYPE);
         $this->assertType('string', $value);
-        $this->assertEquals('foo = 12.34', $value,
+        $this->assertEquals('foo = 12.340000', $value,
             'Incorrect quoteInto() result for FLOAT_TYPE');
 
         $value = $this->_db->quoteInto('foo = ?', 1234, 'CHAR');
@@ -1198,13 +1226,13 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
             'Incorrect quoteInto() result for CHAR');
     }
 
-    public function testAdapterQuoteIntoCount() 
-    { 
-        $value = $this->_db->quoteInto('foo = ? and bar = ?', 1234, null, 1); 
-        $this->assertType('string', $value); 
-        $this->assertEquals('foo = 1234 and bar = ?', $value, 
-            'Incorrect quoteInto() result for count'); 
-    } 
+    public function testAdapterQuoteIntoCount()
+    {
+        $value = $this->_db->quoteInto('foo = ? and bar = ?', 1234, null, 1);
+        $this->assertType('string', $value);
+        $this->assertEquals('foo = 1234 and bar = ?', $value,
+            'Incorrect quoteInto() result for count');
+    }
 
     public function testAdapterQuoteTypeInt()
     {
@@ -1426,7 +1454,10 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
     {
         $value       = ':0\'';
         $valueQuoted = $this->_db->quote($value);
-        $sql = 'SELECT bug_id FROM zfbugs WHERE bug_status != ' . $valueQuoted;
+        $bugs = $this->_db->quoteIdentifier('zfbugs');
+        $bug_id = $this->_db->quoteIdentifier('bug_id');
+        $bug_status = $this->_db->quoteIdentifier('bug_status');
+        $sql = "SELECT $bug_id FROM $bugs WHERE $bug_status != " . $valueQuoted;
         $results = $this->_db->fetchAll($sql);
         $this->assertEquals(4, count($results));
     }
@@ -1698,4 +1729,148 @@ abstract class Zend_Db_Adapter_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(array_fill(0, 4, 'EMPTY'), $value);
     }
 
-}
+    protected function _testAdapterAlternateStatement($stmtClass)
+    {
+        $ip = get_include_path();
+        $dir = dirname(__FILE__) . DIRECTORY_SEPARATOR . '_files';
+        $newIp = $dir . PATH_SEPARATOR . $ip;
+        set_include_path($newIp);
+
+        $params = $this->_util->getParams();
+
+        $params['options'] = array(
+            Zend_Db::AUTO_QUOTE_IDENTIFIERS => false
+        );
+        $db = Zend_Db::factory($this->getDriver(), $params);
+        $db->getConnection();
+        $db->setStatementClass($stmtClass);
+
+        $currentStmtClass = $db->getStatementClass();
+        $this->assertEquals($stmtClass, $currentStmtClass);
+
+        $bugs = $this->_db->quoteIdentifier('zfbugs');
+
+        $stmt = $db->prepare("SELECT COUNT(*) FROM $bugs");
+
+        $this->assertType($stmtClass, $stmt,
+            'Expecting object of type ' . $stmtClass . ', got ' . get_class($stmt));
+    }
+
+    public function testAdapterSetCustomProfiler()
+    {
+        $profilerOptions = array(
+            'enabled'  => true,
+            'class'    => 'stdClass',
+            'instance' => new stdClass()
+        );
+
+        try {
+            $this->_db->setProfiler($profilerOptions);
+            $this->fail('Expected to catch Zend_Db_Profiler_Exception');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Db_Profiler_Exception', $e);
+            $this->assertEquals('Class stdClass does not extend Zend_Db_Profiler', $e->getMessage());
+        }
+    }
+
+    /**
+     * @group ZF-5099
+     */
+    public function testAdapterGetServerVersion()
+    {
+        $version = $this->_db->getServerVersion();
+        $this->assertNotNull($version);
+        $this->assertTrue(version_compare($version, '1.0.0', '>'));
+        $this->assertTrue(version_compare($version, '99.0.0', '<'));
+    }
+
+    public function testAdapterGetConnection()
+    {
+        $this->_db->getConnection();
+        $this->assertTrue($this->_db->isConnected());
+    }
+
+    /**
+     * @group ZF-5050
+     */
+    public function testAdapterCloseConnection()
+    {
+        $this->_db->closeConnection();
+        $this->assertFalse($this->_db->isConnected());
+        // Double closing must be without any errors
+        $this->_db->closeConnection();
+        $this->assertFalse($this->_db->isConnected());
+    }
+
+    /**
+     * @group ZF-5146
+     */
+    public function testAdapterReadClobFetchAll()
+    {
+        $documents = $this->_db->quoteIdentifier('zfdocuments');
+        $document_id = $this->_db->quoteIdentifier('doc_id');
+        $value = $this->_db->fetchAll("SELECT * FROM $documents WHERE $document_id = 1");
+        $expected = 'this is the clob that never ends...'.
+                    'this is the clob that never ends...'.
+                    'this is the clob that never ends...';
+        $this->assertEquals($expected, $value[0]['doc_clob']);
+    }
+
+    /**
+     * @group ZF-5146
+     */
+    public function testAdapterReadClobFetchRow()
+    {
+        $documents = $this->_db->quoteIdentifier('zfdocuments');
+        $document_id = $this->_db->quoteIdentifier('doc_id');
+        $value = $this->_db->fetchRow("SELECT * FROM $documents WHERE $document_id = 1");
+        $expected = 'this is the clob that never ends...'.
+                    'this is the clob that never ends...'.
+                    'this is the clob that never ends...';
+        $this->assertEquals($expected, $value['doc_clob']);
+    }
+
+    /**
+     * @group ZF-5146
+     */
+    public function testAdapterReadClobFetchAssoc()
+    {
+        $documents = $this->_db->quoteIdentifier('zfdocuments');
+        $document_id = $this->_db->quoteIdentifier('doc_id');
+        $value = $this->_db->fetchAssoc("SELECT * FROM $documents WHERE $document_id = 1");
+        $expected = 'this is the clob that never ends...'.
+                    'this is the clob that never ends...'.
+                    'this is the clob that never ends...';
+        $this->assertEquals($expected, $value[1]['doc_clob']);
+    }
+
+    /**
+     * @group ZF-5146
+     */
+    public function testAdapterReadClobFetchCol()
+    {
+        $documents = $this->_db->quoteIdentifier('zfdocuments');
+        $document_id = $this->_db->quoteIdentifier('doc_id');
+        $document_clob = $this->_db->quoteIdentifier('doc_clob');
+        $value = $this->_db->fetchCol("SELECT $document_clob FROM $documents WHERE $document_id = 1");
+        $expected = 'this is the clob that never ends...'.
+                    'this is the clob that never ends...'.
+                    'this is the clob that never ends...';
+        $this->assertEquals($expected, $value[0]);
+    }
+
+    /**
+     * @group ZF-5146
+     */
+    public function testAdapterReadClobFetchOne()
+    {
+        $documents = $this->_db->quoteIdentifier('zfdocuments');
+        $document_id = $this->_db->quoteIdentifier('doc_id');
+        $document_clob = $this->_db->quoteIdentifier('doc_clob');
+        $value = $this->_db->fetchOne("SELECT $document_clob FROM $documents WHERE $document_id = 1");
+        $expected = 'this is the clob that never ends...'.
+                    'this is the clob that never ends...'.
+                    'this is the clob that never ends...';
+        $this->assertEquals($expected, $value);
+    }
+}
\ No newline at end of file
