@@ -11,6 +11,7 @@ require_once 'Zend/Config.php';
 require_once 'Zend/Controller/Action/HelperBroker.php';
 require_once 'Zend/Form.php';
 require_once 'Zend/Form/Decorator/Form.php';
+require_once 'Zend/Form/Decorator/HtmlTag.php';
 require_once 'Zend/Form/Element.php';
 require_once 'Zend/Form/Element/Text.php';
 require_once 'Zend/Loader/PluginLoader.php';
@@ -224,10 +225,9 @@ class Zend_Form_DisplayGroupTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($decorator instanceof Zend_Form_Decorator_ViewHelper);
     }
 
-    public function testCanRetrieveSingleDecoratorRegisteredAsStringUsingClassName()
+    public function testCanNotRetrieveSingleDecoratorRegisteredAsStringUsingClassName()
     {
-        $decorator = $this->group->getDecorator('Zend_Form_Decorator_FormElements');
-        $this->assertTrue($decorator instanceof Zend_Form_Decorator_FormElements);
+        $this->assertFalse($this->group->getDecorator('Zend_Form_Decorator_FormElements'));
     }
 
     public function testCanAddSingleDecoratorAsDecoratorObject()
@@ -427,7 +427,7 @@ class Zend_Form_DisplayGroupTest extends PHPUnit_Framework_TestCase
     public function testGetTranslatorRetrievesGlobalDefaultWhenAvailable()
     {
         $this->testNoTranslatorByDefault();
-        $translator = new Zend_Translate('array', array());
+        $translator = new Zend_Translate('array', array('foo' => 'bar'));
         Zend_Form::setDefaultTranslator($translator);
         $received = $this->group->getTranslator();
         $this->assertSame($translator->getAdapter(), $received);
@@ -435,7 +435,7 @@ class Zend_Form_DisplayGroupTest extends PHPUnit_Framework_TestCase
 
     public function testTranslatorAccessorsWorks()
     {
-        $translator = new Zend_Translate('array', array());
+        $translator = new Zend_Translate('array', array('foo' => 'bar'));
         $this->group->setTranslator($translator);
         $received = $this->group->getTranslator($translator);
         $this->assertSame($translator->getAdapter(), $received);
@@ -553,7 +553,7 @@ class Zend_Form_DisplayGroupTest extends PHPUnit_Framework_TestCase
     public function testSetOptionsOmitsAccessorsRequiringObjectsOrMultipleParams()
     {
         $options = $this->getOptions();
-        $config                  = new Zend_Config($options);
+        $config  = new Zend_Config($options);
         $options['config']       = $config;
         $options['options']      = $config->toArray();
         $options['pluginLoader'] = true;
@@ -703,6 +703,38 @@ class Zend_Form_DisplayGroupTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(empty($decorators));
     }
 
+    /**
+     * @group ZF-3217
+     */
+    public function testGroupShouldOverloadToRenderDecorators()
+    {
+        $foo  = new Zend_Form_Element_Text('foo');
+        $bar  = new Zend_Form_Element_Text('bar');
+        $this->group->addElements(array($foo, $bar));
+
+        $this->group->setView($this->getView());
+        $html = $this->group->renderFormElements();
+        foreach ($this->group->getElements() as $element) {
+            $this->assertContains('id="' . $element->getFullyQualifiedName() . '"', $html, 'Received: ' . $html);
+        }
+        $this->assertNotContains('<dl', $html);
+        $this->assertNotContains('<form', $html);
+
+        $html = $this->group->renderFieldset('this is the content');
+        $this->assertContains('<fieldset', $html);
+        $this->assertContains('</fieldset>', $html);
+        $this->assertContains('this is the content', $html);
+    }
+
+    /**
+     * @group ZF-3217
+     * @expectedException Zend_Form_Exception
+     */
+    public function testOverloadingToInvalidMethodsShouldThrowAnException()
+    {
+        $html = $this->group->bogusMethodCall();
+    }
+
     /**
      * Used by test methods susceptible to ZF-2794, marks a test as incomplete
      *
