@@ -7,27 +7,29 @@ if (! defined('TESTS_ZEND_HTTP_CLIENT_BASEURI') &&
     require_once 'TestConfiguration.php';
 }
 
+require_once realpath(dirname(__FILE__) . '/../../../') . '/TestHelper.php';
+
 require_once 'Zend/Http/Client.php';
 require_once 'PHPUnit/Framework/TestCase.php';
 require_once 'SocketTest.php';
 
 /**
- * This Testsuite includes all Zend_Http_Client that require a working web 
- * server to perform. It was designed to be extendable, so that several 
+ * This Testsuite includes all Zend_Http_Client that require a working web
+ * server to perform. It was designed to be extendable, so that several
  * test suites could be run against several servers, with different client
  * adapters and configurations.
- * 
+ *
  * Note that $this->baseuri must point to a directory on a web server
  * containing all the files under the _files directory. You should symlink
  * or copy these files and set 'baseuri' properly.
- * 
- * You can also set the proper constand in your test configuration file to 
+ *
+ * You can also set the proper constand in your test configuration file to
  * point to the right place.
  *
  * @category   Zend
  * @package    Zend_Http_Client
  * @subpackage UnitTests
- * @version    $Id: SocketKeepaliveTest.php 9910 2008-07-02 22:40:29Z shahar $
+ * @version    $Id: SocketKeepaliveTest.php 12036 2008-10-20 18:37:47Z shahar $
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
