@@ -42,7 +42,6 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $this->_params = array('host'     => TESTS_ZEND_MAIL_IMAP_HOST,
                                'user'     => TESTS_ZEND_MAIL_IMAP_USER,
                                'password' => TESTS_ZEND_MAIL_IMAP_PASSWORD);
-
         if (defined('TESTS_ZEND_MAIL_SERVER_TESTDIR') && TESTS_ZEND_MAIL_SERVER_TESTDIR) {
             if (!file_exists(TESTS_ZEND_MAIL_SERVER_TESTDIR . DIRECTORY_SEPARATOR . 'inbox')
              && !file_exists(TESTS_ZEND_MAIL_SERVER_TESTDIR . DIRECTORY_SEPARATOR . 'INBOX')) {
@@ -295,13 +294,13 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $mail = new Zend_Mail_Storage_Imap($this->_params);
 
         $count = $mail->countMessages();
-        $this->assertEquals(6, $count);
+        $this->assertEquals(7, $count);
     }
 
     public function testSize()
     {
         $mail = new Zend_Mail_Storage_Imap($this->_params);
-        $shouldSizes = array(1 => 397, 89, 694, 452, 497, 101);
+        $shouldSizes = array(1 => 397, 89, 694, 452, 497, 101, 139);
 
 
         $sizes = $mail->getSize();
@@ -733,7 +732,7 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $protocol->login($this->_params['user'], $this->_params['password']);
         $status = $protocol->select('INBOX');
         $this->assertTrue(is_array($status['flags']));
-        $this->assertEquals($status['exists'], 6);
+        $this->assertEquals($status['exists'], 7);
     }
 
 
@@ -743,7 +742,7 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $protocol->login($this->_params['user'], $this->_params['password']);
         $status = $protocol->examine('INBOX');
         $this->assertTrue(is_array($status['flags']));
-        $this->assertEquals($status['exists'], 6);
+        $this->assertEquals($status['exists'], 7);
     }
 
     public function testClosedSocketNewlineToken()
@@ -779,10 +778,10 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $protocol->login($this->_params['user'], $this->_params['password']);
         $protocol->select('INBOX');
 
-        $range = array_combine(range(1, 6), range(1, 6));
+        $range = array_combine(range(1, 7), range(1, 7));
         $this->assertEquals($protocol->fetch('UID', 1, INF), $range);
-        $this->assertEquals($protocol->fetch('UID', 1, 6), $range);
-        $this->assertEquals($protocol->fetch('UID', range(1, 6)), $range);
+        $this->assertEquals($protocol->fetch('UID', 1, 7), $range);
+        $this->assertEquals($protocol->fetch('UID', range(1, 7)), $range);
         $this->assertTrue(is_numeric($protocol->fetch('UID', 1)));
 
         $result = $protocol->fetch(array('UID', 'FLAGS'), 1, INF);
@@ -816,4 +815,38 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $result = $protocol->store(array('\Flagged'), 1, null, '+', false);
         $this->assertTrue(in_array('\Flagged', $result[1]));
     }
+    
+    public function testMove()
+    {
+        $mail = new Zend_Mail_Storage_Imap($this->_params);
+        $mail->selectFolder('subfolder/test');
+        $toCount = $mail->countMessages();
+        $mail->selectFolder('INBOX');
+        $fromCount = $mail->countMessages();
+        $mail->moveMessage(1, 'subfolder/test');
+
+
+        $this->assertEquals($fromCount - 1, $mail->countMessages());
+        $mail->selectFolder('subfolder/test');
+        $this->assertEquals($toCount + 1, $mail->countMessages());
+    }
+
+    public function testCountFlags()
+    {
+        $mail = new Zend_Mail_Storage_Imap($this->_params);
+        foreach ($mail as $id => $message) {
+        	$mail->setFlags($id, array());
+        }
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 0);
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_ANSWERED), 0);
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 0);
+
+		$mail->setFlags(1, array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_ANSWERED));
+		$mail->setFlags(2, array(Zend_Mail_Storage::FLAG_SEEN));
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 2);
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_ANSWERED), 1);
+		$this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_ANSWERED)), 1);
+		$this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_FLAGGED)), 0);
+		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 0);
+    }    	
 }
