@@ -84,19 +84,13 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertContains('<Zend_Rest_Server_TestFunc2 generator="zend" version="1.0"><response>Hello World</response><status>success</status></Zend_Rest_Server_TestFunc2>', $result, "Bad Result");
     }
 
-    public function testHandleFunctionNoArgsThrowsExceptionWithFewerArgs()
+    public function testHandleFunctionNoArgsRaisesFaultResponse()
     {
         $server = new Zend_Rest_Server();
+        $server->returnResponse(true);
         $server->addFunction('Zend_Rest_Server_TestFunc');
-        try {
-            ob_start();
-        	$server->handle(array('method' => 'Zend_Rest_Server_TestFunc'));
-        	ob_end_clean();
-            $this->fail('Call should fail if missing args');
-        } catch (Exception $e) {
-            // success
-            ob_end_clean();
-        }
+        $result = $server->handle(array('method' => 'Zend_Rest_Server_TestFunc'));
+        $this->assertContains('failed', $result);
     }
 
   	public function testHandleFunctionNoArgsUsingRequest()
@@ -336,6 +330,9 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertContains("<foo>bar</foo>", $result, "Bad Result");
     }
 
+    /**
+     * @group ZF-3751
+     */
     public function testHandleInvalidMethod()
     {
         $server = new Zend_Rest_Server();
@@ -343,6 +340,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
         $server->returnResponse(true);
         $response = $server->handle(array('method' => 'test3DomElement'));
         $this->assertContains('<status>failed</status>', $response);
+        $this->assertNotContains('<message>An unknown error occured. Please try again.</message>', $response);
     }
 
     public function testFault()
@@ -470,6 +468,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-1992
+     * @group ZF-1992
      */
     public function testDefaultEncodingShouldBeUtf8()
     {
@@ -479,6 +478,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-1992
+     * @group ZF-1992
      */
     public function testEncodingShouldBeMutableViaAccessors()
     {
@@ -490,6 +490,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-2279
+     * @group ZF-2279
      */
     public function testNamesOfArgumentsShouldDetermineArgumentOrder()
     {
@@ -503,6 +504,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-1949
+     * @group ZF-1949
      */
     public function testMissingArgumentsShouldResultInFaultResponse()
     {
@@ -517,6 +519,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-1949
+     * @group ZF-1949
      */
     public function testMissingArgumentsWithDefaultsShouldNotResultInFaultResponse()
     {
@@ -528,6 +531,32 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertContains('<status>success</status>', $result, var_export($result, 1));
         $this->assertContains('<response>Hello today, How are you Davey</response>', $result, var_export($result, 1));
     }
+
+    /**
+     * @group ZF-3751
+     */
+    public function testCallingUnknownMethodDoesNotThrowUnknownButSpecificErrorExceptionMessage()
+    {
+        $server = new Zend_Rest_Server();
+        $server->setClass('Zend_Rest_Server_Test2');
+        $server->returnResponse(true);
+        $response = $server->handle(array('method' => 'testCallingInvalidMethod'));
+        $this->assertContains('<status>failed</status>', $response);
+        $this->assertNotContains('<message>An unknown error occured. Please try again.</message>', $response);
+    }
+
+    /**
+     * @group ZF-3751
+     */
+    public function testCallingNoMethodDoesNotThrowUnknownButSpecificErrorExceptionMessage()
+    {
+        $server = new Zend_Rest_Server();
+        $server->setClass('Zend_Rest_Server_Test2');
+        $server->returnResponse(true);
+        $response = $server->handle();
+        $this->assertContains('<status>failed</status>', $response);
+        $this->assertNotContains('<message>An unknown error occured. Please try again.</message>', $response);
+    }
 }
 
 /* Test Functions */
