@@ -18,7 +18,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: SessionTest.php 10480 2008-07-26 18:04:58Z alexander $
+ * @version    $Id: SessionTest.php 13338 2008-12-17 11:13:16Z sidhighwind $
  */
 
 
@@ -65,14 +65,25 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
      *
      * @return void
      */
-    public function __construct()
+    public function __construct($name = NULL, array $data = array(), $dataName = '')
     {
-        $this->_script = 'php -c ' . php_ini_loaded_file() . ' '
+        parent::__construct($name, $data, $dataName);
+        $this->_script = 'php -c \'' . php_ini_loaded_file() . '\' '
             . escapeshellarg(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'SessionTestHelper.php');
 
         $this->_savePath = ini_get('session.save_path');
     }
 
+    /**
+     * Set up tests environment
+     */
+    function setUp()
+    {
+        // _unitTestEnabled is utilised by other tests to handle session data processing
+        // Zend_Session tests should pass with _unitTestEnabled turned off
+        Zend_Session::$_unitTestEnabled = false;
+    }
+
     /**
      * Cleanup operations after each test method is run
      *
@@ -134,6 +145,13 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
 
             Zend_Session::start();
         } else {
+            // Start session if it's not actually started
+            // That may happen if Zend_Session::$_unitTestEnabled is turned on while some other
+            // Unit tests utilize Zend_Session functionality
+            if (!defined('SID')) {
+                session_start();
+            }
+
             // only regenerate session id if session has already been started
             Zend_Session::regenerateId();
         }
@@ -141,7 +159,7 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(Zend_Session::isRegenerated());
 
         try {
-            Zend_Session::setId('someo_therid_123');
+            Zend_Session::setId('someo-therid-123');
             $this->fail('No exception was returned when trying to set the session id, after session_start()');
         } catch (Zend_Session_Exception $e) {
             $this->assertRegexp('/already.*started/i', $e->getMessage());
@@ -356,6 +374,23 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
         }
     }
 
+    /**
+     * test for detection of illegal namespace names; expect exception complaining about name beginning
+     * with an underscore
+     *
+     * @return void
+     */
+    public function testInitNamespaceNumber()
+    {
+        try {
+            $s = new Zend_Session_Namespace('0namespace');
+            $this->fail('No exception was returned when requesting a namespace having a name beginning with '
+                . 'a number');
+        } catch (Zend_Session_Exception $e) {
+            $this->assertRegexp('/number/i', $e->getMessage());
+        }
+    }
+
     /**
      * test iteration; expect native PHP foreach statement is able to properly iterate all items in a session namespace
      *
@@ -955,10 +990,19 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
             }
         }
 
-        Zend_Session::destroy();
+        // Do not destroy session since it still may be used by other tests
+        // Zend_Session::destroy();
     }
 
     /**
-     * @todo DO NOT put tests below testSetExpireSessionVarsByHopsOnUse(), since the session is destroy()'d.
+     * @group ZF-5003
      */
+    public function testProcessSessionMetadataShouldNotThrowAnError()
+    {
+        Zend_Session::$_unitTestEnabled = true;
+        if (isset($_SESSION) && isset($_SESSION['__ZF'])) {
+            unset($_SESSION['__ZF']);
+        }
+        Zend_Session::start();
+    }
 }
