@@ -38,6 +38,11 @@ require_once 'Zend/View.php';
  */
 require_once 'Zend/View/Interface.php';
 
+/**
+ * Zend_Loader
+ */
+require_once 'Zend/Loader.php';
+
 /**
  * @category   Zend
  * @package    Zend_View
@@ -74,11 +79,6 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->_testDefaultPath('script', false);
     }
 
-    public function normalizePath($path)
-    {
-        return str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, $path);
-    }
-
     /**
      * Tests that the default helper path is properly initialized
      * and the directory is readable
@@ -136,22 +136,26 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $view = new Zend_View();
 
         $reflector = $view->getAllPaths();
-        $paths     = $reflector[$pathType];
-
+        $paths     = $this->_filterPath($reflector[$pathType]);
+        
         // test default helper path
         $this->assertType('array', $paths);
         if ('script' == $pathType) {
             $this->assertEquals(0, count($paths));
         } else {
             $this->assertEquals(1, count($paths));
-            $item = $paths[0];
 
             $prefix = 'Zend_View_' . ucfirst($pathType) . '_';
-            $this->assertEquals($prefix, $item['prefix']);
+            $this->assertTrue(array_key_exists($prefix, $paths));
 
             if ($testReadability) {
-                $this->assertTrue(is_dir($item['dir']), var_export($item, 1));
-                $this->assertTrue(is_readable($item['dir']));
+                $path = current($paths[$prefix]);
+                
+                if (substr(PHP_OS, 0, 3) != 'WIN') {
+                	$this->assertTrue(Zend_Loader::isReadable($path));
+                } else {
+                	$this->assertTrue(is_dir($path));
+                }
             }
         }
     }
@@ -171,16 +175,14 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $reflector     = $view->getAllPaths();
         $expectedPaths = $reflector[$pathType];
 
-        if ('script' == $pathType) {
-            array_unshift($expectedPaths, 'baz' . DIRECTORY_SEPARATOR);
-            array_unshift($expectedPaths, 'bar' . DIRECTORY_SEPARATOR);
-            array_unshift($expectedPaths, 'foo' . DIRECTORY_SEPARATOR);
-        } else {
-            array_unshift($expectedPaths, array('prefix' => $prefix, 'dir' => 'baz' . DIRECTORY_SEPARATOR));
-            array_unshift($expectedPaths, array('prefix' => $prefix, 'dir' => 'bar' . DIRECTORY_SEPARATOR));
-            array_unshift($expectedPaths, array('prefix' => $prefix, 'dir' => 'foo' . DIRECTORY_SEPARATOR));
+        if ($pathType != 'script') {
+            $expectedPaths = $this->_filterPath($expectedPaths[$prefix]);
         }
 
+        array_push($expectedPaths, 'baz');
+        array_push($expectedPaths, 'bar');
+        array_push($expectedPaths, 'foo');
+
         // add paths
         $func = 'add' . ucfirst($pathType) . 'Path';
         $view->$func('baz');    // no separator
@@ -189,9 +191,18 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         // introspect script paths after adding two new paths
         $reflector   = $view->getAllPaths();
-        $actualPaths = $reflector[$pathType];
+        $actualPaths = $this->_filterPath($reflector[$pathType]);
 
-        $this->assertSame($expectedPaths, $actualPaths);
+        switch ($pathType) {
+            case 'script':
+                $this->assertSame(array_reverse($expectedPaths), $actualPaths);
+                break;
+            case 'helper':
+            case 'filter':
+            default:
+                $this->assertTrue(array_key_exists($prefix, $actualPaths));
+                $this->assertSame($expectedPaths, $actualPaths[$prefix], 'Actual: ' . var_export($actualPaths, 1) . "\nExpected: " . var_export($expectedPaths, 1));
+        }
     }
 
     /**
@@ -233,7 +244,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             )
         );
 
-        $this->assertEquals('foo', $view->stub1());
+        $this->assertEquals('foo', $view->stub1(), var_export($view->getHelperPaths(), 1));
         $this->assertEquals('bar', $view->stub2());
 
         // erase the paths to the helper stubs
@@ -254,8 +265,8 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         try {
             $view->nonexistantHelper();
             // @todo  fail if no exception?
-        } catch (Zend_View_Exception $e) {
-            $this->assertRegexp('/helper [\'a-z]+ not found in path/i', $e->getMessage());
+        } catch (Zend_Exception $e) {
+            $this->assertContains('not found', $e->getMessage());
         }
     }
 
@@ -274,11 +285,22 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             // does not contain the expected class within
             $view->stubEmpty();	
             // @todo  fail if no exception?
-        } catch (Zend_View_Exception $e) {
-            $this->assertRegexp("/['_a-z]+ not found in path/i", $e->getMessage());
+        } catch (Zend_Exception $e) {
+            $this->assertContains("not found", $e->getMessage());
         }
     }
 
+    public function testHelperPathMayBeRegisteredUnderMultiplePrefixes()
+    {
+        $view = new Zend_View();
+
+        $view->addHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1', 'Foo_View_Helper');
+        $view->addHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1', 'Zend_View_Helper');
+
+        $helper = $view->getHelper('Stub1');
+        $this->assertTrue($helper instanceof Foo_View_Helper_Stub1);
+    }
+
     /**
      * Tests that render() can render a template.
      */
@@ -468,9 +490,9 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
     public function testSetConfigInConstructor()
     {
-        $scriptPath = $this->normalizePath(dirname(__FILE__) . '/View/_templates/');
-        $helperPath = $this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/');
-        $filterPath = $this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/');
+        $scriptPath = $this->_filterPath(dirname(__FILE__) . '/View/_templates/');
+        $helperPath = $this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/');
+        $filterPath = $this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/');
 
         $config = array(
             'escape'           => 'strip_tags',
@@ -488,14 +510,17 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $helperPaths = $view->getHelperPaths();
         $filterPaths = $view->getFilterPaths();
 
-        $this->assertContains($this->normalizePath($scriptPath), $scriptPaths);
+        $this->assertContains($this->_filterPath($scriptPath), $this->_filterPath($scriptPaths));
 
         $found  = false;
         $prefix = false;
-        foreach ($helperPaths as $pathInfo) {
-            if (strstr($pathInfo['dir'], $helperPath)) {
-                $found  = true;
-                $prefix = $pathInfo['prefix'];
+        foreach ($helperPaths as $helperPrefix => $paths) {
+            foreach ($paths as $path) {
+                $path = $this->_filterPath($path);
+                if (strstr($path, $helperPath)) {
+                    $found  = true;
+                    $prefix = $helperPrefix;
+                }
             }
         }
         $this->assertTrue($found, var_export($helperPaths, 1));
@@ -503,10 +528,13 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         $found  = false;
         $prefix = false;
-        foreach ($filterPaths as $pathInfo) {
-            if (strstr($pathInfo['dir'], $filterPath)) {
-                $found  = true;
-                $prefix = $pathInfo['prefix'];
+        foreach ($filterPaths as $classPrefix => $paths) {
+            foreach ($paths as $pathInfo) {
+                $path = $this->_filterPath($pathInfo);
+                if (strstr($pathInfo, $filterPath)) {
+                    $found  = true;
+                    $prefix = $classPrefix;
+                }
             }
         }
         $this->assertTrue($found, var_export($filterPaths, 1));
@@ -538,15 +566,15 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $status = $view->addHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/', 'My_View_Helper');
         $this->assertSame($view, $status);
         $helperPaths = $view->getHelperPaths();
-        $path = $helperPaths[0];
-        $this->assertEquals('My_View_Helper_', $path['prefix']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $path['dir']);
+        $this->assertTrue(array_key_exists('My_View_Helper_', $helperPaths));
+        $path = $this->_filterPath(current($helperPaths['My_View_Helper_']));
+        $this->assertEquals($this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $path);
 
         $view->setHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/', 'Other_View_Helper');
         $helperPaths = $view->getHelperPaths();
-        $path = $helperPaths[0];
-        $this->assertEquals('Other_View_Helper_', $path['prefix']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $path['dir']);
+        $this->assertTrue(array_key_exists('Other_View_Helper_', $helperPaths));
+        $path = $this->_filterPath(current($helperPaths['Other_View_Helper_']));
+        $this->assertEquals($this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $path);
     }
 
     public function testHelperPathWithPrefixAndRelativePath()
@@ -555,9 +583,8 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $status = $view->addHelperPath('Zend/View/_stubs/HelperDir1/', 'My_View_Helper');
         $this->assertSame($view, $status);
         $helperPaths = $view->getHelperPaths();
-        $path = $helperPaths[0];
-        $this->assertEquals('My_View_Helper_', $path['prefix']);
-        $this->assertContains($this->normalizePath('Zend/View/_stubs/HelperDir1/'), $path['dir']);
+        $this->assertTrue(array_key_exists('My_View_Helper_', $helperPaths));
+        $this->assertContains($this->_filterPath('Zend/View/_stubs/HelperDir1/'), $this->_filterPath(current($helperPaths['My_View_Helper_'])));
     }
 
     public function testFilterPathWithPrefix()
@@ -566,15 +593,13 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $status = $view->addFilterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/', 'My_View_Filter');
         $this->assertSame($view, $status);
         $filterPaths = $view->getFilterPaths();
-        $path = $filterPaths[0];
-        $this->assertEquals('My_View_Filter_', $path['prefix']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $path['dir']);
+        $this->assertTrue(array_key_exists('My_View_Filter_', $filterPaths));
+        $this->assertEquals($this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $this->_filterPath(current($filterPaths['My_View_Filter_'])));
 
         $view->setFilterPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/', 'Other_View_Filter');
         $filterPaths = $view->getFilterPaths();
-        $path = $filterPaths[0];
-        $this->assertEquals('Other_View_Filter_', $path['prefix']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $path['dir']);
+        $this->assertTrue(array_key_exists('Other_View_Filter_', $filterPaths));
+        $this->assertEquals($this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $this->_filterPath(current($filterPaths['Other_View_Filter_'])));
     }
 
     public function testAssignThrowsExceptionsOnBadValues()
@@ -691,7 +716,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
     public function testSetBasePathFromConstructor()
     {
-        $base = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'View';
+        $base = dirname(__FILE__) . '/View';
         $view = new Zend_View(array('basePath' => $base));
         $this->_testBasePath($view, $base);
     }
@@ -711,20 +736,39 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->_testBasePath($view, $base);
     }
 
+    protected function _filterPath($path)
+    {
+        if (is_array($path)) {
+            foreach ($path as $k => $p) {
+                $path[$k] = $this->_filterPath($p);
+            }
+            return $path;
+        }
+
+        $path = str_replace(DIRECTORY_SEPARATOR, '/', $path);
+        $path = str_replace('//', '/', $path);
+        $path = rtrim($path, '/');
+        return $path;
+    }
+
     protected function _testBasePath(Zend_View $view, $base, $classPrefix = null)
     {
-        $scriptPaths = $view->getScriptPaths();
-        $helperPaths = $view->getHelperPaths();
-        $filterPaths = $view->getFilterPaths();
-        $this->assertContains($base . DIRECTORY_SEPARATOR . 'scripts' . DIRECTORY_SEPARATOR, $scriptPaths);
+        $base        = $this->_filterPath($base);
+        $scriptPaths = $this->_filterPath($view->getScriptPaths());
+        $helperPaths = $this->_filterPath($view->getHelperPaths());
+        $filterPaths = $this->_filterPath($view->getFilterPaths());
+        $this->assertContains($base  . '/scripts', $scriptPaths);
 
         $found  = false;
         $prefix = false;
-        foreach ($helperPaths as $path) {
-            if ($path['dir'] == $base . DIRECTORY_SEPARATOR . 'helpers' . DIRECTORY_SEPARATOR) {
-                $found  = true;
-                $prefix = $path['prefix'];
-                break;
+        foreach ($helperPaths as $pathPrefix => $paths) {
+            foreach ($paths as $path) {
+                $path = $this->_filterPath($path);
+                if ($path == $base . '/helpers') {
+                    $found  = true;
+                    $prefix = $pathPrefix;
+                    break;
+                }
             }
         }
         $this->assertTrue($found, var_export($helperPaths, 1));
@@ -735,11 +779,14 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         $found  = false;
         $prefix = false;
-        foreach ($filterPaths as $path) {
-            if ($path['dir'] == $base . DIRECTORY_SEPARATOR . 'filters' . DIRECTORY_SEPARATOR) {
-                $found  = true;
-                $prefix = $path['prefix'];
-                break;
+        foreach ($filterPaths as $pathPrefix => $paths) {
+            foreach ($paths as $path) {
+                $path = $this->_filterPath($path);
+                if ($path == $base . '/filters') {
+                    $found  = true;
+                    $prefix = $pathPrefix;
+                    break;
+                }
             }
         }
         $this->assertTrue($found, var_export($filterPaths, 1));
@@ -800,7 +847,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $view = new Zend_View();
         $view->declareVars();
         $helperPath = $view->getHelperPath('declareVars');
-        $this->assertEquals($expected, $helperPath);
+        $this->assertContains($expected, $helperPath);
     }
 
     public function testGetFilter()
@@ -826,7 +873,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $view->addFilterPath($base . '_stubs' . DIRECTORY_SEPARATOR . 'FilterDir1');
 
         $filterPath = $view->getFilterPath('foo');
-        $this->assertEquals($expected, $filterPath);
+        $this->assertEquals($expected, $filterPath, var_export($filterPath, 1));
     }
 
     public function testGetFilters()
@@ -891,21 +938,111 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
             $view->setHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1', null);
             $this->fail('Exception for empty prefix was expected.');
         } catch (Exception $e) {
-            $this->assertEquals('The classPrefix cannot be empty.', $e->getMessage());
+            $this->assertContains('only takes strings', $e->getMessage());
         }
 
         try {
             $view->setHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir1', null);
             $this->fail('Exception for empty prefix was expected.');
         } catch (Exception $e) {
-            $this->assertEquals('The classPrefix cannot be empty.', $e->getMessage());
+            $this->assertContains('only takes strings', $e->getMessage());
         }
         
         
-        $helper = $view->getHelper('Datetime');
-        $this->assertEquals('Zend_View_Helper_Datetime', get_class($helper));
+        try {
+            $helper = $view->getHelper('Datetime');
+        } catch (Exception $e) {
+            $this->assertContains('not found', $e->getMessage());
+        }
+    }
+
+    public function testUseStreamWrapperFlagShouldDefaultToFalse()
+    {
+        $this->view = new Zend_View();
+        $this->assertFalse($this->view->useStreamWrapper());
     }
     
+    public function testUseStreamWrapperStateShouldBeConfigurable()
+    {
+        $this->testUseStreamWrapperFlagShouldDefaultToFalse();
+        $this->view->setUseStreamWrapper(true);
+        $this->assertTrue($this->view->useStreamWrapper());
+        $this->view->setUseStreamWrapper(false);
+        $this->assertFalse($this->view->useStreamWrapper());
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testRenderShouldNotAllowScriptPathsContainingParentDirectoryTraversal()
+    {
+        $view = new Zend_View();
+        try {
+            $view->render('../foobar.html');
+            $this->fail('Should not allow parent directory traversal');
+        } catch (Zend_View_Exception $e) {
+            $this->assertContains('parent directory traversal', $e->getMessage());
+        }
+
+        try {
+            $view->render('foo/../foobar.html');
+            $this->fail('Should not allow parent directory traversal');
+        } catch (Zend_View_Exception $e) {
+            $this->assertContains('parent directory traversal', $e->getMessage());
+        }
+
+        try {
+            $view->render('foo/..\foobar.html');
+            $this->fail('Should not allow parent directory traversal');
+        } catch (Zend_View_Exception $e) {
+            $this->assertContains('parent directory traversal', $e->getMessage());
+        }
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testLfiProtectionFlagShouldBeEnabledByDefault()
+    {
+        $view = new Zend_View();
+        $this->assertTrue($view->isLfiProtectionOn());
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testLfiProtectionFlagMayBeDisabledViaConstructorOption()
+    {
+        $view = new Zend_View(array('lfiProtectionOn' => false));
+        $this->assertFalse($view->isLfiProtectionOn());
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testLfiProtectionFlagMayBeDisabledViaMethodCall()
+    {
+        $view = new Zend_View();
+        $view->setLfiProtection(false);
+        $this->assertFalse($view->isLfiProtectionOn());
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testDisablingLfiProtectionAllowsParentDirectoryTraversal()
+    {
+        $view = new Zend_View(array(
+            'lfiProtectionOn' => false,
+            'scriptPath'      => dirname(__FILE__) . '/View/_templates/',
+        ));
+        try {
+            $test = $view->render('../_stubs/scripts/LfiProtectionCheck.phtml');
+            $this->assertContains('LFI', $test);
+        } catch (Zend_View_Exception $e) {
+            $this->fail('LFI attack failed: ' . $e->getMessage());
+        }
+    }
 }
 
 /**
